(* automata.ml *)
(* Contient des fonctions de manipulations basique de l’automate représentant un nœud. *)

open Syntax
open Utils

type automate =
        {
                mutable input : int list;
                mutable output : int list;
                mutable local : int list;

                mutable transition_formula : Syntax.expression;

                mutable states : Syntax.expression list array;
                mutable output_prop : Syntax.expression array;
                
                mutable init_states : int list;
                mutable transitions : (int * int * Syntax.expression) list
        }

let trivial_automata () = {
                input = [];
                output = [];
                local = [];
                transition_formula = from_bool true;
                states = [|[]|];
                output_prop = [|from_bool true|];
                init_states = [0];
                transitions = [0, 0, from_bool true];
        }

let empty_automata () = {
                input = [];
                output = [];
                local = [];
                transition_formula = from_bool true;
                states = [||];
                output_prop = [||];
                init_states = [];
                transitions = [];
        }


let set_automata node a =
        a.input <- node.Syntax.input;
        a.output <- node.Syntax.output;
        a.local <- node.Syntax.temporary;
        a.local <- List.fold_left (fun l (id, _, _) -> id :: l) a.local node.Syntax.memory;
        ()

let cp_automata aut1 aut2 =
        aut1.input <- aut2.input;
        aut1.output <- aut2.output;
        aut1.local <- aut2.local;
        aut1.states <- aut2.states;
        aut1.transition_formula <- aut2.transition_formula;
        aut1.transitions <- aut2.transitions;
        ()


let automata_table = Hashtbl.create 10 (* int -> Automata.automate *)

let give_automata i a =
        Hashtbl.add automata_table i a

let get_automata i =
        try Hashtbl.find automata_table i with
        | Not_found -> failwith ("the node or function “" ^ Alpha.get_name i ^ "” seems not have been analysed.")


let transform_expression state pre_state automata args ret =
        let assoc_in = List.map2 (fun a b -> a, b) automata.input args in
        let assoc_out = List.map2 (fun a b -> a, (Ident b, Op [], Alpha.get_type b)) automata.output ret in
        let assoc = assoc_in @ assoc_out in
        let rec mk binaire neutre = function
                | [] -> neutre
                | [a] -> a
                | a :: l -> binaire, Op [a ; mk binaire neutre l], TBool
        in
        let mk_or = mk Or (from_bool false) in
        let mk_and = mk And (from_bool true) in
        let n = Array.length automata.states in
        let eg var n =
                Eq, Op [Ident var, Op [], TInt ; Int (Mpzf.of_int n), Op [], TInt], TInt
        in
        let rec convert_prop = function
                | Ident i, _, _ -> (try List.assoc i assoc with Not_found -> failwith ("variable “" ^ Alpha.get_name i ^ "” doesn’t appears neither on input nor on output variables."))
                | c, Op l, t -> c, Op (List.map convert_prop l), t
        in
        let trans i j =
                try
                        let _, _, in_prop = List.find (fun (a, b, _) -> a = i && b = j) automata.transitions in
                        mk_and [eg pre_state i; eg state j;
                        convert_prop (in_prop);
                        convert_prop (automata.output_prop.(j))]
                with Not_found -> from_bool false; (* La transition n’existe pas. *)
        in
        mk_or (List.concat (create_list (fun i -> create_list (fun j -> trans (i - 1) (j - 1)) n) n))

let initialisation_automate state automata =
        let egal i =
                (Eq, Op [Ident state, Op [], TInt ; Int (Z.of_int i), Op [], TInt], TBool)
        in
        make_or (List.map egal automata.init_states)

