(* automata.mli *)
(* Contient des fonctions de manipulations basique de l’automate représentant un nœud. *)

type automate =
        {
                mutable input : int list;
                mutable output : int list;
                mutable local : int list;

                mutable transition_formula : Syntax.expression;

                mutable states : Syntax.expression list array;
                mutable output_prop : Syntax.expression array; (* Les propriétés sur les variables de sortie. *)
                
                mutable init_states : int list;
                mutable transitions : (int * int * Syntax.expression) list
               (* Aller d’un état i à un état j. La première expression est la
                * condition sur les entrées pour ceci. *)
        }

val trivial_automata : unit -> automate
val empty_automata : unit -> automate

val set_automata : Syntax.node -> automate -> unit
(* Cette fonction part du principe que les transitions et les états ont déjà
 * été générés. *)

val cp_automata : automate -> automate -> unit (* cp_automata copie original *)

val transform_expression : int -> int -> automate -> Syntax.expression list -> int list -> Syntax.expression
val initialisation_automate : int -> automate -> Syntax.expression

(* J’aurais préféré que ces fonctions soient dans alpha.ml, mais à cause de
 * dépendances croisée, je ne peux pas. *)
val give_automata : int -> automate -> unit
val get_automata : int -> automate

