(* alpha.ml *)
(* Contient toutes les fonctions permettant de passer de string à int pour les
 * identifiants. *)

open Hashtbl

let global_table = create 10 (* string -> int *)
let reverse_table = create 10 (* int -> string *)
let type_table = create 10 (* int -> Syntax.type_var *)
let id = ref 0

let get_fresh_id t =
        add type_table !id t;
        incr id;
        !id - 1

let get_new_id name t =
        add global_table name !id;
        add reverse_table !id name;
        add type_table !id t;
        incr id;
        !id - 1

let get_ident name =
        try find global_table name with
        | Not_found -> raise (Errors.Name_not_in_table name)

let get_name id =
        try find reverse_table id with
        | Not_found -> "<anymous>"

let get_type id =
        try find type_table id with
        | Not_found -> failwith "request for the type of an untyped object."

let remove id =
        let name = get_name id in
        remove reverse_table id;
        remove global_table name;
        remove type_table id

let rec get_new_name s =
        try let _ = get_ident s
        in get_new_name ("_" ^ s ^ "_") with
        | Errors.Name_not_in_table _ -> s

let var_ident id =
        let ty = get_type id in
                (Syntax.Ident id, Syntax.Op [], ty)

let yices_var = create 10 (* (int * int) -> (expr * var_decl) *) (* Le premier entier représente le numéro du contexte *)

let rec search_type_in_record f context_id = function
    | (id, t) :: _ when id = context_id -> t
    | _ :: l -> search_type_in_record f context_id l
    | [] -> f ()

let liste_int = ref []
let liste_real = ref []

let int_type = function context -> function context_id ->
        search_type_in_record (fun () -> let t = Yices.mk_type context "int" in liste_int := (context_id, t) :: !liste_int; t) context_id !liste_int

let real_type = function context -> function context_id ->
        search_type_in_record (fun () -> let t = Yices.mk_type context "real" in liste_real := (context_id, t) :: !liste_real; t) context_id !liste_real

let give_yices_var context context_id id =
    let x_name = "v" ^ string_of_int id ^ "c" ^ string_of_int context_id in
    (* J’aurais aussi pu prendre le nom de la variable, mais je crains que ça ne soit un peu moins rapide. *)
    let x_decl =
    match get_type id with
    | Syntax.TBool -> Yices.mk_bool_var_decl context x_name
    | t ->
            let x_type = match t with
                            | Syntax.TBool -> failwith "internal error in Alpha.give_yices_var."
                            | Syntax.TInt -> int_type context context_id
                            | Syntax.TReal -> real_type context context_id
                            | Syntax.TTuple _ -> failwith "trying to create a Yices variable from a tuple."
            in
            Yices.mk_var_decl context x_name x_type
    in
    let x = Yices.mk_var_from_decl context x_decl in
    add yices_var (context_id, id) (x, x_decl)

let get_yices_var cont id =
    try fst (find yices_var (cont, id)) with
    | Not_found -> raise (Errors.Name_not_in_table (get_name id))

let iter_on_yices_var context_id f =
        let g (cont, id) (_, decl) =
                if cont = context_id then f id decl
        in
        iter g yices_var

let reset_yices_var () =
        clear yices_var;
        liste_int := [];
        liste_real := [];
        ()

