(* Syntax.ml *)
(* Contient la définition des nœuds pour le reste du programme. *)

type op_call =
        (* zéroaire *)
        | True
        | False
        | Int of Mpzf.t
        | Real of Mpqf.t
        | Ident of int
        (* unaires *)
        | Not
        | Uminus
        | Int2Real
        | Real2Int
        (* Binaires *)
        | Arrow (* -> *)
        | And
        | Or
        | Xor
        | Impl (* => *)
        | Eq (* = *)
        | Neq
        | Gte
        | Gt
        | Lte
        | Lt
        | Div
        | Mod
        | Minus
        | Plus
        | Times
        (* Ternaires *)
        | If
        (* n-aires *)
        | Nor
        | Diese
        | Tuple
        (* Appel de fonction *)
        | Call of int
(* Noter que l’opérateur pre n’apparaît que par l’intermédiare des variables
 * mémoires *)

type type_var =
        | TBool
        | TInt
        | TReal
        | TTuple of type_var list

type expression = op_call * op_arg * type_var
and op_arg = Op of expression list


type node =
        {
                mutable id : int;

                mutable input : int list;
                mutable output : int list;
                mutable temporary : int list;

                mutable assume : int;

                mutable memory : (int * int * int) list; (* Va contenir des triplets
        (identifiant_de_la_variable,
        identifiant_de_la_variable_suivie, nb_de_décalages) *)

                mutable equations : (int list * expression) list
        }

let from_bool b =
        ((if b then True else False), Op [], TBool)

let from_int i =
        (Int i, Op [], TInt)

let from_float f =
        (Real f, Op [], TReal)

let rec make_form neutre connecteur t = function
        | [] -> neutre, Op [], t
        | [a] -> a
        | a :: l -> connecteur, Op [a ; make_form neutre connecteur t l], t

let make_and = make_form True And TBool
let make_or = make_form False Or TBool
let make_xor = make_form False Xor TBool

let make_sum = make_form (Int Z.zero) Plus TInt
let make_prod = make_form (Int Z.one) Times TInt

