(* Syntax.mli *)
(* Contient la définition des nœuds pour le reste du programme. *)

type op_call =
        (* zéroaire *)
        | True
        | False
        | Int of Mpzf.t
        | Real of Mpqf.t
        | Ident of int
        (* unaires *)
        | Not
        | Uminus
        | Int2Real
        | Real2Int
        (* Binaires *)
        | Arrow (* -> *)
        | And
        | Or
        | Xor
        | Impl (* => *)
        | Eq (* = *)
        | Neq
        | Gte
        | Gt
        | Lte
        | Lt
        | Div
        | Mod
        | Minus
        | Plus
        | Times
        (* Ternaires *)
        | If
        (* n-aires *)
        | Nor (* Aucun n’est vrai *)
        | Diese (* Au plus un d’eux est vrai *)
        | Tuple
        (* Appel de fonction *)
        | Call of int

type type_var =
        | TBool
        | TInt
        | TReal
        | TTuple of type_var list

type expression = op_call * op_arg * type_var
and op_arg = Op of expression list

type node =
        {
                mutable id : int;

                mutable input : int list;
                mutable output : int list;
                mutable temporary : int list;

                mutable assume : int; (* Contient l’identifiant de la variable qui correspond aux « assert » du programme. *)

                mutable memory : (int * int * int) list; (* Va contenir des triplets
        (identifiant_de_la_variable,
        identifiant_de_la_variable_suivie, nb_de_décalages) *)

                mutable equations : (int list * expression) list
        }


val from_bool : bool -> expression
val from_int : Mpzf.t -> expression
val from_float : Mpqf.t -> expression

val make_and : expression list -> expression
val make_or : expression list -> expression
val make_xor : expression list -> expression

val make_sum :  expression list -> expression
val make_prod :  expression list -> expression

