(* invariants.mli *)
(* Contient des fonctions calculant les modes de fonctionnement d’un nœud. *)

type arg =
        {
                mutable just_a_little_verbose : bool;
                mutable verbose : bool;
                mutable print : string -> unit;
                mutable print_T : Syntax.expression list list -> unit;

                mutable minimal : bool;
                mutable size : int;

                mutable search_better_size : bool;
                mutable max_size : int;

                mutable removal_of_permutation : bool;
                mutable removal_of_subsumed_disjuncts : bool;
                mutable satisfiable : bool;
                mutable variante_eviter_seg_fault_yices : bool;

                mutable find_better_strictly : bool;

                mutable expand_invariant : bool;

                mutable generate_automata : bool;
        }

val default : arg

(* Les fonctions qui prennent deux entiers en argument prennent dans l’ordre n
 * puis m. *)

val init : int -> int -> unit

val init_context_from_predicates : int -> int -> Syntax.expression list -> unit
(* Définit les prédicats pi_i et leur donne une variable associée b_{i,j}. *)

val set_transition_formula : Syntax.expression -> unit
(* Prend en argument la formule donnée par Logic_node.logic_transition_of_node (avec des variables primées donc.) *)

val set_initial_formula : Syntax.expression -> unit

val init_formula : unit -> unit

val init_constraint : arg -> int -> int -> unit
(* Ajoute les contraintes pour enlever les problèmes de permutation des C_i,
 * ainsi que d’autres optimisations. *)

val add_constraint_to_found_a_better_solution_than : Syntax.expression list list -> unit
val test_better : Syntax.expression list list -> Syntax.expression list list -> bool


val solve : arg -> (unit -> Syntax.expression list list) -> Syntax.expression list list
(* Fait les calculs et renvoit l’invariant trouvé. *)

val get_automata : unit -> Automata.automate

val reset : unit -> unit

