(* smt.ml *)
(* Contient des fonctions qui utilisent Yices. *)

open Syntax
open Yices


let mk_and_nsf c = function (* Juste pour éviter de Seg Faulter avec Yices. *)
        | [] -> mk_true c
        | [a] -> a
        | l -> mk_and c l

let mk_or_nsf c = function
        | [] -> mk_false c
        | [a] -> a
        | l -> mk_or c l


let implique context a b =
        mk_or_nsf context [mk_not context a ; b]

let rec convert_expr contexte contexte_id = function
    | True, _, _ -> mk_true contexte
    | False, _, _ -> mk_false contexte
    | Int i, _, _ -> mk_num_from_mpz contexte i
    | Real r, _, _ -> mk_num_from_mpq contexte r

    | Ident id, _, _ -> (try Alpha.get_yices_var contexte_id id with
                        | Errors.Name_not_in_table _ -> Alpha.give_yices_var contexte contexte_id id; Alpha.get_yices_var contexte_id id)

    | Not, Op [e], _ -> mk_not contexte (convert_expr contexte contexte_id e)
    | Uminus, Op [e], _ -> mk_sub contexte [mk_num_from_mpz contexte Z.zero; convert_expr contexte contexte_id e]

    | And, Op [e1 ; e2], _ -> mk_and_nsf contexte [convert_expr contexte contexte_id e1 ; convert_expr contexte contexte_id e2]
    | Or, Op [e1 ; e2], _ -> mk_or_nsf contexte [convert_expr contexte contexte_id e1 ; convert_expr contexte contexte_id e2]
    | Impl, Op [e1 ; e2], _ -> implique contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)

    | Eq, Op [e1 ; e2], _ -> mk_eq contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)
    | (Neq | Xor), Op [e1 ; e2], _ -> mk_diseq contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)

    | Gt, Op [e1 ; e2], _ -> mk_gt contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)
    | Gte, Op [e1 ; e2], _ -> mk_ge contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)
    | Lt, Op [e1 ; e2], _ -> mk_lt contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)
    | Lte, Op [e1 ; e2], _ -> mk_le contexte (convert_expr contexte contexte_id e1) (convert_expr contexte contexte_id e2)
    | Plus, Op [e1 ; e2], _ -> mk_sum contexte [convert_expr contexte contexte_id e1 ; convert_expr contexte contexte_id e2]
    | Minus, Op [e1 ; e2], _ -> mk_sub contexte [convert_expr contexte contexte_id e1 ; convert_expr contexte contexte_id e2]
    | Times, Op [e1 ; e2], _ -> mk_mul contexte [convert_expr contexte contexte_id e1 ; convert_expr contexte contexte_id e2]

    | Nor, Op l, _ -> mk_not contexte (mk_and_nsf contexte (List.map (convert_expr contexte contexte_id) l))
    | Diese, Op l, _ ->
              let l' = List.map (convert_expr contexte contexte_id) l in
              let rec foo prec = function
                      | [] -> mk_and_nsf contexte (List.map (mk_not contexte) prec)
                      | a :: suiv ->
                              mk_or_nsf contexte [(mk_and_nsf contexte (a :: List.map (mk_not contexte) prec @ List.map (mk_not contexte) suiv)) ; foo (a :: prec) suiv]
              in
              foo [] l'

    | (Call _ | If | Arrow | Tuple), _, _ -> failwith "Smt.convert_expr shouldn’t meet any call, if, arrow or tuple. Try using the right options (-st or -sif)."

    | _ -> raise Errors.Not_implemented (* FIXME: la division ne sera pas simple à implémenter, mais elle reste possible. *)


