(* solve.ml *)
(* Contient des fonctions appelant les fonctions de invariants.ml pour avoir une
 * meilleur interface. *)

open Automata
open Invariants
open Smt


let init n m pred transition initialisation options =
       init n m; (* Réinitialise les tableaux et leur donne la taille voulue. *)
       init_context_from_predicates n m pred; (* Initialise les prédicats pi dans les différents contextes, ainsi que les booléens b_ij. *)
       set_transition_formula transition;
       set_initial_formula initialisation;
       init_formula (); (* Initialise la formule F. *)
       init_constraint options n m;
       ()

let search pred transition initialisation arg =
        let automata = trivial_automata () in (* Oui, puisque je n’ai pas fait quelque chose de fonctionnel, il faut copier l’automate, dommage. *)
        let m = List.length pred in
        let rec part ancienne_solution =
        try
                init arg.size m pred transition initialisation arg;
                if not arg.variante_eviter_seg_fault_yices then add_constraint_to_found_a_better_solution_than ancienne_solution;
                let used = ref false in
                let solution = solve arg (fun () -> used := true; ancienne_solution)
                in
                reset ();
                if !used then
                begin (* Aucune solution meilleur n’a été trouvée : on garde l’ancienne sans refaire le moindre calcul. *)
                        if arg.generate_automata then cp_automata (get_automata ()) automata;
                        ancienne_solution
                end
                else
                begin (* Une nouvelle solution a été trouvée. *)
                        (if arg.variante_eviter_seg_fault_yices then
                                (fun a ->
                                        if arg.verbose then arg.print ("An invariant has been found with " ^ string_of_int arg.size ^ "clause" ^ (if arg.size = 1 then "" else "s") ^ ".\n" ^ "Testing if it is better than the preceding one.\n");
                                        if test_better solution ancienne_solution then a ()
                                        else ancienne_solution
                                )
                        else
                                (fun a -> a ()))
                        (fun () ->
                        if arg.generate_automata then cp_automata automata (get_automata ());
                        if arg.search_better_size then
                        begin
                                if arg.just_a_little_verbose then arg.print ("Invariant found with " ^ string_of_int arg.size ^ " clause" ^ (if arg.size = 1 then "" else "s") ^ ".\n");
                                if arg.verbose then
                                begin
                                        arg.print ("An invariant has been found with " ^ string_of_int arg.size ^ " clause" ^ (if arg.size = 1 then "" else "s") ^ ".\n");
                                        if arg.size = arg.max_size then arg.print "This is the imposed limit.\nTaking this invariant as a final invariant.\n\n"
                                        else arg.print "Trying to found one better with one more.\n\n"
                                end;
                                if arg.size = arg.max_size then solution (* On est content avec ce que l’on a. *)
                                else
                                begin
                                        arg.size <- arg.size + 1;
                                        part solution
                                end
                        end
                        else
                        begin
                                if arg.generate_automata then cp_automata (get_automata ()) automata;
                                solution
                        end)
                end
        with
                | Failure "there is not enough predicates to found a solution with so many clauses." ->
                        if arg.verbose then arg.print "Limits for the number of clauses reached.\nTaking the lastest invariant found.\n\n";
                        if arg.generate_automata then cp_automata (get_automata ()) automata;
                        ancienne_solution
        in
        if arg.verbose then arg.print "true is an inductive invariant, let’s try to find a better one.\n";
        part [[]]

