(*---------------------------------------------------
-- FONCTION PRINCIPALE : exp_clock
--
-- Restriction : les expressions, mme tuple,
-- doivent tre mono-clock
----------------------------------------------------*)
exception Clock_error of string 

let rec exp_clock (ctx : env) (e : Syntaxe.val_exp) = (
	match e with (nat, Ops ops) ->
	(* On calcule d'ores et dja la liste des clocks des arguments *)
	let cops = List.map (exp_clock ctx) ops in
	match nat with
	(* constantes => base clock *)
   	TRUE_n     
	|  FALSE_n    
	|  ICONST_n s 
	|  RCONST_n s 
	|  IVAL_n   i 
	|  RVAL_n   r -> BaseClock
	(* ident => voir ctx *)
	|  IDENT_n  s -> ident_clock ctx s
	(* current *)
	|	CURRENT_n  -> (
		match cops with
			(NamedClock s)::[] -> (
				ident_clock ctx s
			) |
			_ -> (
				raise (Global_error "exp_clock : unexpected case in CURRENT_n")
			)
	)
	(* when *)
	|	WHEN_n  -> (
		match cops with
			c0::c1::[] -> (
				if (c0 = c1) then (
					match (List.nth ops 1) with
						(Ident_n s , _ ) -> NamedClock s
					|	_ -> (
						raise (Clock_error("snd operand of when must be a var"))
					) 
				) else (
					raise (Clock_error("operands not on same clock"))
				)
			)
			_ -> (
				raise (Global_error "exp_clock : unexpected case in WHEN_n")
			)
	)
	(* cas gnral *)
	|	_ -> (
		match cops with
			c0 :: t -> (
				let check_clock c = (
					if (c = c0) then ()
					else (
						raise (Clock_error("operands not on same clock"))
					)
				) in
				List.iter check_clock t ;
				c0
			)
		|	_ -> (
			raise (Global_error "exp_clock : unexpected case")
		)
	)
) and 
let rec ident_clock (ctx : env) (s : string) = (
	try (
		Hashtbl.find  ctx.flow_clock_tab s
	) with Not_found -> (
		raise(Global_error("exp_clock:  undeclared flow: "^s))
	)
)
