(* Note de Martin : J'ai ajout quelques "ignore" dans le code pour viter
 * tous les "usued variables" de Caml. *)

(*
	SANS AUCUNE VERIF
	Dump d'un package em syntaxe lustre de "base"
	Dans l'ordre de dclaration

TRICHERIES :
	- pour les acces  champs nomms, on recherche
	le premier type dont in champ correspond
	- pour les noeuds/fonctions sans entres :
     .  la def on rajoute un param dummy : bool
     .  l'appel on rajoute un arg true 

OPERATEURS VS APPELS DE FONCTION :
	le dump peut tre parametr par une table qui indique
	quels oprateurs prdfinis (sous certaine condition 
	de type) doivent tre affichs comme des appels 
	de fonctions.
*)
open Syntaxe
open Lexeme
open Format
open XecErrors
open Typing

(*
	Par dfaut, on traite int comme un type predef
*)
let dump_usr_int = ref false;;

(* la table qui associe aux oper predef entier une fonction externe *)
let usr_int_calls = Hashtbl.create 50;;

Hashtbl.add usr_int_calls (UMINUS_n, [TE_int]) "UsrIntChs";;
Hashtbl.add usr_int_calls (EQ_n, [TE_int;TE_int]) "UsrIntEq";;
Hashtbl.add usr_int_calls (NEQ_n, [TE_int;TE_int]) "UsrIntNeq";;
Hashtbl.add usr_int_calls (GTE_n, [TE_int;TE_int]) "UsrIntGte";;
Hashtbl.add usr_int_calls (GT_n, [TE_int;TE_int]) "UsrIntGt";;
Hashtbl.add usr_int_calls (LTE_n, [TE_int;TE_int]) "UsrIntLte";;
Hashtbl.add usr_int_calls (LT_n, [TE_int;TE_int]) "UsrIntLt";;
Hashtbl.add usr_int_calls (DIV_n, [TE_int;TE_int]) "UsrIntDiv";;
Hashtbl.add usr_int_calls (MOD_n, [TE_int;TE_int]) "UsrIntMod";;
Hashtbl.add usr_int_calls (MINUS_n, [TE_int;TE_int]) "UsrIntMinus";;
Hashtbl.add usr_int_calls (PLUS_n, [TE_int;TE_int]) "UsrIntPlus";;
Hashtbl.add usr_int_calls (SLASH_n, [TE_int;TE_int]) "UsrIntDiv";;
Hashtbl.add usr_int_calls (TIMES_n, [TE_int;TE_int]) "UsrIntTimes";;
Hashtbl.add usr_int_calls (IF_n, [TE_bool;TE_int;TE_int]) "UsrIntIf";;

let get_usr_int_func 
	(ctx    : Typing.env)
	(nature : Syntaxe.op_call)
	(ops    : Syntaxe.val_exp list) 
= (
	if (!dump_usr_int) then  (
		let opts = List.flatten (List.map (Typing.exp_type ctx) ops) in
		try (
			Hashtbl.find usr_int_calls (nature, opts)
		) with Not_found -> raise Failed
	) else (
		raise Failed
	)
) 

let get_usr_int_const s = (
	if (!dump_usr_int) then  (
		"UsrInt_"^s
	) else (
		s
	)
) 

(* pareil pour les reels *)

let dump_usr_real = ref false;;
let usr_real_calls = Hashtbl.create 50;;
Hashtbl.add usr_real_calls (UMINUS_n, [TE_real]) "UsrRealChs";;
Hashtbl.add usr_real_calls (EQ_n, [TE_real;TE_real]) "UsrRealEq";;
Hashtbl.add usr_real_calls (NEQ_n, [TE_real;TE_real]) "UsrRealNeq";;
Hashtbl.add usr_real_calls (GTE_n, [TE_real;TE_real]) "UsrRealGte";;
Hashtbl.add usr_real_calls (GT_n, [TE_real;TE_real]) "UsrRealGt";;
Hashtbl.add usr_real_calls (LTE_n, [TE_real;TE_real]) "UsrRealLte";;
Hashtbl.add usr_real_calls (LT_n, [TE_real;TE_real]) "UsrRealLt";;
Hashtbl.add usr_real_calls (MINUS_n, [TE_real;TE_real]) "UsrRealMinus";;
Hashtbl.add usr_real_calls (PLUS_n, [TE_real;TE_real]) "UsrRealPlus";;
Hashtbl.add usr_real_calls (SLASH_n, [TE_real;TE_real]) "UsrRealDiv";;
Hashtbl.add usr_real_calls (TIMES_n, [TE_real;TE_real]) "UsrRealTimes";;
Hashtbl.add usr_real_calls (IF_n, [TE_bool;TE_real;TE_real]) "UsrRealIf";;

let get_usr_real_func 
	(ctx    : Typing.env)
	(nature : Syntaxe.op_call)
	(ops    : Syntaxe.val_exp list) 
= (
	if (!dump_usr_real) then  (
		let opts = List.flatten (List.map (Typing.exp_type ctx) ops) in
		try (
			Hashtbl.find usr_real_calls (nature, opts)
		) with Not_found -> raise Failed
	) else (
		raise Failed
	)
) 

let correct_real s = (
	let len = (String.length s) in
	let r = String.create len in
	for i = 0 to len-1 do
		match s.[i] with
			'-' -> r.[i] <- 'm'
		|	'+' -> r.[i] <- 'p'
		|	'.' -> r.[i] <- '_'
		|	c -> r.[i] <- c
	done;
	r
)

let get_usr_real_const s = (
	if (!dump_usr_real) then  (
		let ns = correct_real s in
		"UsrReal_"^ns
	) else (
		s
	)
) 

(* pareil pour les booleens *)

let dump_usr_bool = ref false;;
let usr_bool_calls = Hashtbl.create 50;;
Hashtbl.add usr_bool_calls (NOT_n, [TE_bool]) "UsrBoolNot";;
Hashtbl.add usr_bool_calls (EQ_n, [TE_bool;TE_bool]) "UsrBoolEq";;
Hashtbl.add usr_bool_calls (NEQ_n, [TE_bool;TE_bool]) "UsrBoolNeq";;
Hashtbl.add usr_bool_calls (AND_n, [TE_bool;TE_bool]) "UsrBoolAnd";;
Hashtbl.add usr_bool_calls (OR_n, [TE_bool;TE_bool]) "UsrBoolOr";;
Hashtbl.add usr_bool_calls (IMPL_n, [TE_bool;TE_bool]) "UsrBoolImpl";;
Hashtbl.add usr_bool_calls (XOR_n, [TE_bool;TE_bool]) "UsrBoolXor";;
Hashtbl.add usr_bool_calls (IF_n, [TE_bool;TE_bool;TE_bool]) "UsrBoolIf";;

let get_usr_bool_func 
	(ctx    : Typing.env)
	(nature : Syntaxe.op_call)
	(ops    : Syntaxe.val_exp list) 
= (
	if (!dump_usr_bool) then  (
		let opts = List.flatten (List.map (Typing.exp_type ctx) ops) in
		try (
			Hashtbl.find usr_bool_calls (nature, opts)
		) with Not_found -> raise Failed
	) else (
		raise Failed
	)
) 

let get_usr_bool_const s = (
	if (!dump_usr_bool) then  (
		"UsrBool"^s
	) else (
		s
	)
) 

(*
	retourne la liste des 
	acces  plat d'un objet de
	type compose 
*)

let search_field_index ctx zefield = (
	let res = ref (-1) in
        let find_field tname teff = ignore tname; (
		match teff with 
                TE_struct (n, fl) -> ignore n; (
			let cpt = ref 0 in
                        let searchf (fn, ft) = ignore ft; (
				if(fn = zefield) then (
					if(!res != -1) then (
						raise (Global_error ("field not unique"))
					) else (
						res := !cpt
					)
				) else ();
				incr cpt
			) in
			List.iter searchf fl
		) |
		 _ -> ()
	) in
	Typing.iter_on_types ctx find_field ;
	match !res with
	-1 -> raise (Global_error ("can'y find field"))
	| v -> v
)

let rec print_coma_list = (function
		[] -> ()
	|	[x] -> print_string x
	|	x::t -> (
		print_string (x^", ") ;
		print_coma_list t
	)	
)

let const_int_of_val_exp = (
	function 
	(*{ exp_nature = (ICONST_n s); exp_operands = [] }*)
	(ICONST_n s, Ops [])
	    -> int_of_ecint s
	| _ -> raise (Global_error ("integer const expected"))
)


let rec dump_type_exp (ctx : Typing.env) (te : type_exp) = (
	match te with
	   Bool -> (
			if(!dump_usr_bool) then print_string "UsrBool"
			else print_string "bool"
		)
	|  Int  -> (
			if(!dump_usr_int) then print_string "UsrInt"
			else print_string "int"
		)
	|  Real -> (
			if(!dump_usr_real) then print_string "UsrReal"
			else print_string "real"
		)
	|  NamedType nme -> print_string nme
	|  ArrayType (tr, sz) -> (
			dump_type_exp ctx tr ;
			(*match sz.exp_nature with*)
			match (fst sz) with
				ICONST_n i ->	print_string ("^"^i)
			| _ -> raise (Global_error "only constant array size implemented")
		)
	|  TupleType tl -> (
			let dumpt = function t -> (
				print_string ", ";
				dump_type_exp ctx t	
			) in
			print_string "[";
			(match (tl) with
				[] -> raise (Global_error "empty tuple type") 
				| t::r -> (
					dump_type_exp ctx t ;
					List.iter dumpt r
				)
			);
			print_string "]";
		)
)

(* quand le pack n'est pas necessaire ...*)
let dummy_pack = {
   const_table = Hashtbl.create 0;
   type_table  = Hashtbl.create 0;
   oper_table  = Hashtbl.create 0;
   def_list    = [] ; 
};;

let dump_val_exp (ctx : Typing.env) (e : val_exp) = (
	let rec print_exp  (e : val_exp) = (
		let dump_unary (s : string) (op : val_exp) = (
			print_string (s^"(") ;
			print_exp op;
			print_string ")"
		) in
		let dump_binary (s : string) (op0 : val_exp) (op1 : val_exp) = (
			print_string "(";
			print_exp op0;
			print_string (" "^s^" ");
			print_exp op1;
			print_string ")"
		) in
		let dump_nary (pfx : string) (sep : string) 
                        (sfx : string) (ops : val_exp list) = ignore sep; (
			print_string pfx;
			print_exp (List.hd ops);
			let dump_other_op (op : val_exp) = (
				print_string ", "; print_exp op
			) in
			List.iter dump_other_op (List.tl ops);
			print_string sfx
		) in
		(* let nat = e.exp_nature in *)
		(* let ops = e.exp_operands in *)
		let nat = Syntaxe.exp_nat e in
		let ops = Syntaxe.exp_ops e in
		(* AVANT TOUTE CHOSE, ON ESSAI UN TRAITEMENT SPECIAL *)
		try (
			let f = get_usr_int_func ctx nat ops in
			dump_nary (f^" (") "," ")" ops
		) with Failed -> 
		try (
			let f = get_usr_real_func ctx nat ops in
			dump_nary (f^" (") "," ")" ops
		) with Failed ->
		try (
			let f = get_usr_bool_func ctx nat ops in
			dump_nary (f^" (") "," ")" ops
		) with Failed -> (
			match nat with
				TRUE_n-> (
				let c = get_usr_bool_const "true" in
				print_string c
			)
			|	FALSE_n-> (
				let c = get_usr_bool_const "false" in
				print_string c
			)
			(* ICI *)
			|	ICONST_n s  -> (
				let c = get_usr_int_const s in
				print_string c
			)
			|	IVAL_n i  -> (
				let c = get_usr_int_const (Syntaxe.ecint_of_int i) in
				print_string c 
			)
			|	RCONST_n s-> (
				let c = get_usr_real_const s in
				print_string c
			)
			|	RVAL_n f -> (
				let c = get_usr_real_const (Syntaxe.ecreal_of_float f) in
				print_string c 
			)
			|	IDENT_n  s -> (print_string s)
			(* unaires *)
			|	PRE_n-> (dump_unary "pre" (List.hd ops))
			|	CURRENT_n-> (dump_unary "current" (List.hd ops))
			|	NOT_n-> (dump_unary "not" (List.hd ops))
			|	UMINUS_n-> (dump_unary "-" (List.hd ops))
			|	INT2REAL_n-> (dump_unary "real" (List.hd ops))
			|	REAL2INT_n-> (dump_unary "int" (List.hd ops))
			(* binaires *)
			|	ARROW_n-> (dump_binary "->" (List.nth ops 0) (List.nth ops 1))
			|	WHEN_n-> (dump_binary "when" (List.nth ops 0) (List.nth ops 1))
			|	AND_n-> (dump_binary "and" (List.nth ops 0) (List.nth ops 1))
			|	OR_n-> (dump_binary "or" (List.nth ops 0) (List.nth ops 1))
			|	XOR_n-> (dump_binary "xor" (List.nth ops 0) (List.nth ops 1))
			|	IMPL_n-> (dump_binary "=>" (List.nth ops 0) (List.nth ops 1))
			|	EQ_n-> (dump_binary "=" (List.nth ops 0) (List.nth ops 1))
			|	NEQ_n-> (dump_binary "<>" (List.nth ops 0) (List.nth ops 1))
			|	GTE_n-> (dump_binary ">=" (List.nth ops 0) (List.nth ops 1))
			|	GT_n-> (dump_binary ">" (List.nth ops 0) (List.nth ops 1))
			|	LTE_n-> (dump_binary "<=" (List.nth ops 0) (List.nth ops 1))
			|	LT_n-> (dump_binary "<" (List.nth ops 0) (List.nth ops 1))
			|	DIV_n-> (dump_binary "div" (List.nth ops 0) (List.nth ops 1))
			|	MOD_n-> (dump_binary "mod" (List.nth ops 0) (List.nth ops 1))
			|	MINUS_n-> (dump_binary "-" (List.nth ops 0) (List.nth ops 1))
			|	PLUS_n-> (dump_binary "+" (List.nth ops 0) (List.nth ops 1))
			|	SLASH_n-> (dump_binary "/" (List.nth ops 0) (List.nth ops 1))
			|	TIMES_n-> (dump_binary "*" (List.nth ops 0) (List.nth ops 1))
			|	HAT_n-> (dump_binary "^" (List.nth ops 0) (List.nth ops 1))
			(* ternaires *)
			|	IF_n-> (
					print_string "if ("; 
					print_exp (List.nth ops 0);
					print_string ") then ("; 
					print_exp (List.nth ops 1);
					print_string ") else ("; 
					print_exp (List.nth ops 2);
					print_string ")" 
			)
			(* n-aires *)
			|	NOR_n-> (dump_nary "nor (" "," ")" ops)
			|	DIESE_n-> (dump_nary "# (" "," ")" ops)
			|	TUPLE_n-> (dump_nary "(" "," ")" ops)
			|	ARRAY_n-> (dump_nary "[" "," "]" ops)
			(* call 
			*)
			|	CALL_n s -> (
				match ops with
					[] -> (print_string (s^"(true (*__DUMMY*))")) 
				|	_  -> dump_nary (s^" (") "," ")" ops
			)
			(* pseudo-unaire : acces tableau par val_exp *)
			|	ARRAY_ACCES_n ix -> (
				print_exp (List.hd ops);
				print_string "[";
				print_exp ix;
				print_string "]";
			)
			(* pseudo-unaire : acces tableau par slice_info *)
                        |	ARRAY_SLICE_n sl-> ignore sl; (
				raise (Global_error "array slicing not implemented")
			)
			(* pseudo-unaire : acces structure par string *)
			|	STRUCT_ACCESS_n fl -> (
				let ix = search_field_index ctx fl in
				print_exp (List.hd ops);
				print_string ("["^(string_of_int ix)^"]")
			)
			(* pseudo-unaire : select dans un tuple *)
			|	SELECT_n ix -> (
				print_exp (List.hd ops);
				print_string ("["^(string_of_int ix)^"]")
			)
			|	_  -> (
				raise (Global_error "_TO_type not implemented")
			)
		)
	) in
	print_exp e
)

let dump_simple_exp (e : val_exp) = (
	dump_val_exp Typing.empty_env e
)


let dump_const_def (ctx : Typing.env) (c : const_info) = (
	match c with
	ExternalConst (n, t) -> (
		print_string ("const "^n^" : ");
		dump_type_exp ctx t;
		print_string ";\n"
	) |
	DefinedConst (n, None, v) -> (
		print_string ("const "^n^" = ");
		dump_val_exp ctx v;
		print_string ";\n"
	) |
        DefinedConst (n, Some t, v) -> ignore t; (
		print_string ("const "^n^" = ");
		dump_val_exp ctx v;
		print_string ";\n"
	)
)

let dump_type_def (ctx : Typing.env) (c : type_info) = (
	match c with
	ExternalType nme -> (
		print_string ("type "^nme^";\n")
	) |
	AliasedType (nme,te) -> (
		print_string ("type "^nme^" = ");
		dump_type_exp ctx te;
		print_string ";\n"
	) |
        EnumType nme -> ignore nme; (
		raise (Global_error "enumerate types not implemented")
	) | 
	StructType (nme, fields) -> (
                let pfield = function (s, t) -> ignore s; dump_type_exp ctx t in
                let pfield2 = function (s, t) -> ignore s; (
			print_string ", ";
			dump_type_exp ctx t
		) in
		print_string ("type "^nme^" = [");
		pfield (List.hd fields);
		List.iter pfield2 (List.tl fields);
		print_string "];\n"
	)
)
let dump_typed_ident ctx t = (
	print_string ((fst t)^" : ");
	dump_type_exp ctx (snd t)
)
let rec dump_typed_ident_list ctx tl = (
	match tl with
		[] -> ()
	| x::[] -> (dump_typed_ident ctx x)
	| x::t  -> (
		dump_typed_ident ctx x; 
		print_string "; ";
		dump_typed_ident_list ctx t
	)
)
let dump_typed_clocked_ident ctx v = (
	match v with 
	(n,t,BaseClock) -> (
		print_string (n^" : ");
		dump_type_exp ctx t
	) |
	(n,t,NamedClock c) -> (
		print_string ("("^n^" : ");
		dump_type_exp ctx t;
		print_string (") when "^c)
	)
)
let rec dump_typed_clocked_ident_list ctx tl = (
	match tl with
		[] -> ()
	| x::[] -> (
		print_string "   ";
		dump_typed_clocked_ident ctx x
	)
	| x::t  -> (
		print_string "   ";
		dump_typed_clocked_ident ctx x; 
		print_string ";\n";
		dump_typed_clocked_ident_list ctx t
	)
)

(*
OPERATEURS : NODE ET FUNCTION

On force un argument bidon boolen
*)
let dump_func_def (ctx : Typing.env) (f : func_info) = (
	print_string ("function "^(f.fi_name)^" (\n");
	(match f.fi_inpars with 
		[] -> (print_string "__DUMMY : bool")
	|	_  -> (dump_typed_ident_list ctx f.fi_inpars)
	);
	print_string "\n) returns (\n";
	dump_typed_ident_list ctx f.fi_outpars;
	print_string "\n);\n"
)

let dump_node_def (ctx : Typing.env) (n : node_info) = (
	print_string ("node "^(n.ni_name)^" (\n");
	(match n.ni_inputs with 
		[] -> (print_string "__DUMMY : bool")
	|	_  -> (dump_typed_clocked_ident_list ctx n.ni_inputs)
	);
	print_string "\n) returns (\n";
	dump_typed_clocked_ident_list ctx n.ni_outputs;
	print_string "\n);\n";
	if(n.ni_locals != []) then (
		print_string "var\n";
		dump_typed_clocked_ident_list ctx n.ni_locals;
		print_string ";\n";
	) else ();
	print_string "let\n";
	let dump_assert a = (
		print_string "   assert ";
		dump_val_exp ctx a;
		print_string ";\n"
	) in
	List.iter dump_assert n.ni_asserts;
	let dump_left = function
			LeftVar s -> print_string s
		|	LeftArray (s, e) -> (
				print_string (s^"[");
				dump_val_exp ctx e;
				print_string "]"
			)
		|	_ -> raise (Global_error "selector in left part not implemented")
	in
	let rec dump_left_list = function
		[] -> ()
		| l::[] -> dump_left l
		| l::t  -> dump_left l; print_string ", "; dump_left_list t
	in
	let dump_def d = (
		print_string "   ";
		dump_left_list (fst d);
		print_string " = ";
		dump_val_exp ctx (snd d);
		print_string ";\n"
	) in
	List.iter dump_def n.ni_defs;
	print_string "tel\n"
)

let dump_pack (p : package) = (
	let genv = Typing.get_env p None in
	let dump_def_item (d : def_item) = (
		match d with
		ConstDef nme -> (
			let def = Hashtbl.find p.const_table nme in
			dump_const_def genv def.it
		)|
		TypeDef nme -> (
			let def = Hashtbl.find p.type_table nme in
			dump_type_def genv def.it
		)|
		OperDef nme -> (
			let def = Hashtbl.find p.oper_table nme in
			match (def.it) with
				FuncOper f -> (
					dump_func_def genv f
				) |
				NodeOper n -> (
					let lenv = Typing.get_env p (Some n) in
					dump_node_def lenv n
				)
		)
	) in
	List.iter dump_def_item (p.def_list)
)
