%{
open Lexing
open Lexeme
open Syntaxe

let parse_error (str) = (
	()
)

let mainresult = {
   const_table = Hashtbl.create 50 ;
   type_table  = Hashtbl.create 50 ;
   func_table  = Hashtbl.create 50 ;
   node_table  = Hashtbl.create 50 
}

let add_one_external_const typ id = (
	Hashtbl.add mainresult.const_table id (ExternalConst (id,typ));
	typ
)

let add_external_consts lst typ = (
	let dummy = List.fold_left add_one_external_const typ lst in ()
)
%}

%token TK_EOF

%token <string> TK_ERROR

%token <string> TK_AND
%token <string> TK_ARROW
%token <string> TK_ARROW
%token <string> TK_ASSERT
%token <string> TK_BAR
%token <string> TK_BOOL
%token <string> TK_CDOTS
%token <string> TK_CLOSE_BRACE
%token <string> TK_CLOSE_BRACKET
%token <string> TK_CLOSE_PAR
%token <string> TK_COLON
%token <string> TK_COMA
%token <string> TK_CONST
%token <string> TK_CURRENT
%token <string> TK_DIV
%token <string> TK_DOT
%token <string> TK_EQ
%token <string> TK_ELSE
%token <string> TK_ENUM
%token <string> TK_FALSE
%token <string> TK_FIELD
%token <string> TK_FUNCTION
%token <string> TK_GT
%token <string> TK_GTE
%token <string> TK_HAT
%token <string> TK_ICONST
%token <string> TK_IDENT
%token <string> TK_IF
%token <string> TK_IMPL
%token <string> TK_INT
%token <string> TK_LET
%token <string> TK_LT
%token <string> TK_LTE
%token <string> TK_MINUS
%token <string> TK_MOD
%token <string> TK_NEQ
%token <string> TK_NODE
%token <string> TK_NOR
%token <string> TK_NOT
%token <string> TK_OPEN_BRACE
%token <string> TK_OPEN_BRACKET
%token <string> TK_OPEN_PAR
%token <string> TK_OR
%token <string> TK_PCENT
%token <string> TK_PLUS
%token <string> TK_POWER
%token <string> TK_PRE
%token <string> TK_RCONST
%token <string> TK_REAL
%token <string> TK_RETURNS
%token <string> TK_SEMICOL
%token <string> TK_SLASH
%token <string> TK_STAR
%token <string> TK_STEP
%token <string> TK_STRUCT
%token <string> TK_TEL
%token <string> TK_THEN
%token <string> TK_TRUE
%token <string> TK_TYPE
%token <string> TK_VAR
%token <string> TK_WHEN
%token <string> TK_WITH
%token <string> TK_XOR

/* Priorities */

%left TK_ELSE
%left TK_BAR
%left TK_ARROW
%nonassoc TK_STEP
%nonassoc TK_CDOTS
%left TK_OR TK_XOR
%left TK_AND
%nonassoc TK_LT TK_LTE TK_EQ TK_GTE TK_GT TK_NEQ TK_IMPL 
%nonassoc TK_NOT
%left TK_PLUS TK_MINUS
%left TK_STAR TK_SLASH TK_PCENT TK_MOD TK_DIV
%left TK_POWER
%left TK_WHEN
%nonassoc TK_INT TK_REAL
%nonassoc TK_UMINUS TK_PRE TK_CURRENT TK_DIESE TK_NOR
%left TK_HAT TK_FIELD TK_DOT
%right TK_OPEN_BRACKET TK_OPEN_BRACE TK_SEMICOL
%right TK_COMA

/* sxEntry point */
%start sxLusFile
%type <Syntaxe.package option> sxLusFile

%%

/*-------------------------------------------------------
	GRAMMAR
---------------------------------------------------------
NOTES ON THE CODE:

- Nothing is "build" for the main list declarations :
each definition is directly inserted in the corresponding
hash table (i.e. each declaration makes a side effect)

- Any rule that produces a caml list builds it in THE REVERSE
ORDER (in order to save the yacc stack and to avoid
the use of the caml @ operator). This is why they are
named "sxTotoReverseList". This is why they must not be
used in other rules: onr have to use the corresponding
"sxTotoList" which finally reverse the list.
-------------------------------------------------------*/

/*
WARNING 
*/

sxLusFile:	/* empty */ TK_EOF
			{ None }
	|   sxDeclList TK_EOF
			{ Some mainresult }
	;

/* sxDeclarations */

sxDeclList:   sxOneDecl
			{ }
	|   sxDeclList sxOneDecl
			{ }
	;

sxOneDecl:
		sxConstDecl 
			{ }
	|	sxTypeDecl
			{ }
	|	sxFuncDecl
			{ } 
	|	sxNodeDecl
			{ }
	;

/* sxIdentifiers and lists */
sxIdent : TK_IDENT
	{ $1 }
	;

sxIdentList:   sxIdent
			{ [$1] }
	|   sxIdentList TK_COMA sxIdent
			{ $3::$1 }
	; 

sxTypedIdentsList: sxTypedIdents
			{ [ $1 ] }
	|   sxTypedIdentsList TK_SEMICOL sxTypedIdents
			{ $3::$1 }
	;

sxTypedIdents:   sxIdentList TK_COLON sxType
			{ ($1 , $3 ) }
	;


/* constantes */

sxConstDecl:   TK_CONST sxConstDeclList 
			{}
	;

sxConstDeclList:   sxOneConstDecl TK_SEMICOL
			{}
	|   sxConstDeclList sxOneConstDecl TK_SEMICOL
			{}
	|	error TK_SEMICOL
			{}
	;

sxOneConstDecl: 
	/* Il faut au - le type ou la valeur ou les deux ! */
		sxIdentList TK_COLON sxType 
		{
			(add_external_consts (List.rev $1) Bool)
		}
	|  sxIdentList TK_EQ sxExpression
			{}
	|  sxIdentList TK_COLON sxType TK_EQ sxExpression
			{}
	; 


/* types */

sxTypeDecl:   TK_TYPE sxTypeDeclList
			{} 
	;

sxTypeDeclList:   sxOneTypeDecl TK_SEMICOL
			{}
	|   sxTypeDeclList sxOneTypeDecl TK_SEMICOL
			{}
	|	error TK_SEMICOL
			{}
	;

sxOneTypeDecl:
		/* liste de types abstraits (externes) */
		sxIdentList
			{}
	|
		/* un type defini */
	   sxIdent TK_EQ sxTypeDef 
			{}
	;

sxTypeDef:
		/* un simple "alias" sur un type immdiat */
		sxType
			{}
		/* ou une vraie dfinition */
	|	sxUserType
			{}
	;

/* Notation de type "immdiat" */
sxType:
		/* prdfini */
		sxPredefinedType
			{}
		/* ou nomm */
	|	sxIdent
			{}
		/* ou tableau immdiat */
	|	sxType TK_HAT sxExpression
			{} 
	;

sxPredefinedType:
	   TK_BOOL 
			{}
	|   TK_INT 
			{}
	|   TK_REAL
			{}
	;

/* Dfinition de types non immdiats */
sxUserType:
	/* type numr */
	   TK_ENUM TK_OPEN_BRACE sxIdentList TK_CLOSE_BRACE
			{}
	/* type structure  champs nomms */
	|  TK_STRUCT TK_OPEN_BRACE sxTypedIdentsList TK_CLOSE_BRACE
			{}
	;


/* fonctions */

sxFuncDecl:   TK_FUNCTION sxIdent sxFunParam TK_RETURNS sxFunParam sxOptSemicol
			{ }
	;


sxFunParam:   TK_OPEN_PAR sxTypedIdentsList TK_CLOSE_PAR
			{}
   |   TK_OPEN_PAR sxTypedIdentsList TK_SEMICOL TK_CLOSE_PAR
         {}
   |   TK_OPEN_PAR TK_CLOSE_PAR
         {}
	;


/* noeuds */

sxNodeDecl:   sxLocalNode
			{}
	;

sxLocalNode:   TK_NODE sxHeader sxLocals sxBody sxOptEndNode
			{}
	;

/* Le "."  la fin des noeuds est une fioriture historique,
	On accepte donc '.' ';' ou rien du tout !
*/
sxOptEndNode:
		TK_DOT
			{}
	|	sxOptSemicol
			{}
	;

/* en-tete de noeud */

sxHeader:	   sxIdent sxInParam TK_RETURNS sxOutParam sxOptSemicol
			{}
	;

sxInParam:   TK_OPEN_PAR sxInParamDeclList TK_CLOSE_PAR
			{}
   |   TK_OPEN_PAR sxInParamDeclList TK_SEMICOL TK_CLOSE_PAR
         {}
   |   TK_OPEN_PAR TK_CLOSE_PAR
         {}
	;

sxInParamDeclList:   sxInParamDecl
			{}
	|    sxInParamDeclList TK_SEMICOL sxInParamDecl
			{}
	;

sxInParamDecl: sxTypedIdents 
			{}
	|   TK_CONST sxTypedIdents
			{}
	|  TK_OPEN_PAR sxTypedIdentsList TK_CLOSE_PAR TK_WHEN sxIdent
			{}
	;

sxOutParam:   TK_OPEN_PAR sxVarDeclList TK_CLOSE_PAR
			{}
   |    TK_OPEN_PAR sxVarDeclList TK_SEMICOL TK_CLOSE_PAR
			{}
	|   TK_OPEN_PAR TK_CLOSE_PAR
		{}
	;

sxVarDeclList: sxVarDecl
			{}
	|    sxVarDeclList TK_SEMICOL sxVarDecl
			{}
	;

sxVarDecl: sxTypedIdents 
			{}
	| sxTypedIdents TK_WHEN sxIdent
			{}
	|  TK_OPEN_PAR sxTypedIdentsList TK_CLOSE_PAR TK_WHEN sxIdent
			{}
	;

sxLocals:	/* empty */
			{}
	|    TK_VAR sxVarDeclList TK_SEMICOL
			{}
	;

/* sxCorps d'un noeud */

sxBody:
      TK_LET TK_TEL
         {}
	|   TK_LET sxEquationList TK_TEL
			 {}
	|	error TK_TEL
			{}
	;

/* sxLes sxEquations */

sxEquationList:   sxEquation
			{}
	|   sxEquationList sxEquation
			{}
	;

sxEquation:   TK_ASSERT sxExpression TK_SEMICOL
			{}
	|   sxLeft TK_EQ sxExpression TK_SEMICOL
			{}
	|	error TK_SEMICOL
			 {}
	;

/* partie gauche d'equation */

sxLeft:	   sxLeftItemList
			{}
	|   TK_OPEN_PAR sxLeftItemList TK_CLOSE_PAR
			{}
	;

sxLeftItemList:   sxLeftItem
			{}
	|   sxLeftItemList TK_COMA sxLeftItem 
			{}
	;

sxLeftItem: sxIdent
			{}
	|   sxFieldLeftItem 
			{}
	|   sxTableLeftItem
			{}
	;


sxFieldLeftItem: sxLeftItem sxFieldAcces
		{}
	;

sxFieldAcces: TK_FIELD  TK_ICONST 
   {
		(* syntax_warning(&($2), "obsolete struct access"); *)
	}
   |  TK_DOT sxIdent
   	{}
	;

sxTableLeftItem:
	|   sxLeftItem TK_OPEN_BRACKET sxSelect TK_CLOSE_BRACKET
			{}
	;

sxSelect: sxExpression
		{}
	|   sxExpression TK_CDOTS sxExpression sxStep
		{}
	;

sxStep: /* empty */
			{}
	|   TK_STEP sxExpression
			{}
	;


/* partie droite d'equation (expression) */

sxExpression: 
	   sxConstant
			{}
	|   sxIdent 
			{}
	|   TK_NOT sxExpression
			{}
	|   TK_MINUS sxExpression %prec TK_UMINUS
			{}
	|   TK_PRE sxExpression
			{}
	|   TK_CURRENT sxExpression
			{}
	|   TK_INT sxExpression 
			{}
	|   TK_REAL sxExpression 
			{}
	|  sxExpression TK_ARROW sxExpression
			{}
	|  sxExpression TK_WHEN sxExpression
			{}
	|  TK_IF sxExpression TK_THEN sxExpression TK_ELSE sxExpression
			{}
	|  TK_WITH sxExpression TK_THEN sxExpression TK_ELSE sxExpression
			{}
	|  sxExpression TK_XOR sxExpression
			{}
	|  sxExpression TK_IMPL sxExpression
			{}
	|  sxExpression TK_OR sxExpression
			{}
	|  sxExpression TK_AND sxExpression
			{}
	|  sxExpression TK_EQ sxExpression
			{}
	|  sxExpression TK_NEQ sxExpression
			{}
	|  sxExpression TK_LT sxExpression
			{}
	|  sxExpression TK_LTE sxExpression
			{}
	|  sxExpression TK_GT sxExpression
			{}
	|  sxExpression TK_GTE sxExpression
			{}
	|  sxExpression TK_STAR sxExpression
			{}
	|  sxExpression TK_SLASH sxExpression
			{}
	|  sxExpression TK_PCENT sxExpression
			{}
	|  sxExpression TK_MOD sxExpression
			{}
	|  sxExpression TK_DIV sxExpression
			{}
	|  sxExpression TK_PLUS sxExpression
			{}
	|  sxExpression TK_MINUS sxExpression
			{}
	|  sxExpression TK_POWER sxExpression
			{}
	|	sxCallByPosExpression 
			{}
	|	sxCallByNameExpression 
			{}
/* Oprations sur les tableaux */
	|  TK_OPEN_BRACKET sxExpressionList TK_CLOSE_BRACKET
			{}
	|  sxExpression TK_HAT sxExpression
			{}
	|  sxExpression TK_BAR sxExpression
			{}
	|  sxExpression TK_OPEN_BRACKET sxSelect TK_CLOSE_BRACKET 
			{}
/* Acces aux structures */
	|  sxExpression sxFieldAcces
			{}
/* Oprations n-aires */
	|  TK_DIESE TK_OPEN_PAR sxExpList2 TK_CLOSE_PAR
			{}
	|  TK_NOR TK_OPEN_PAR sxExpList2 TK_CLOSE_PAR
			{}
/* Parenthses */
	|  TK_OPEN_PAR sxExpression TK_CLOSE_PAR
			{}
/* Tuple */
	|  TK_OPEN_PAR sxExpList2 TK_CLOSE_PAR
			{}
	;

/* Appel fonctionnel par position (classique) */
/* NB
	On a 2 rgles  cause des appels chantillonn
*/
sxCallByPosExpression:
		sxIdent TK_OPEN_PAR sxExpression TK_CLOSE_PAR
		{}
	|	sxIdent TK_OPEN_PAR sxExpList2 TK_CLOSE_PAR
		{}
	;

/* Appel fonctionnel par nom */
/* NB
Actuellement, uniquement pour les structures,
donc pas de soucis d'chantillonnage
*/
sxCallByNameExpression:
	sxIdent TK_OPEN_BRACE sxCallByNameParamList sxOptSemicol TK_CLOSE_BRACE
		{}
	;

sxCallByNameParamList:
		sxCallByNameParam
			{}
	|
		sxCallByNameParamList TK_SEMICOL sxCallByNameParam	
			{}
	;

sxCallByNameParam:
		sxIdent TK_EQ sxExpression
			{}
	;

sxExpressionList:   sxExpression
			{}
	|   sxExpList2 
			{}
	;

sxConstant:   TK_TRUE
			{}
	|   TK_FALSE
			{}
	|    TK_ICONST 
			{}
	|   TK_RCONST
			{}
	;

sxExpList2: sxExpressionList TK_COMA sxExpression 
			{}
	;

/* NB
Syntaxe laxiste des listes :
quand il n'y a pas d'ambiguit,
les ";" sont vus indifferemment commme 
des sparateurs ou des terminateurs
*/
sxOptSemicol :
		/* empty */
		{}
	|   TK_SEMICOL 
		{}
	;
