(*
Interface des parsers 
*)


open Lexeme;;
open Verbose;;
open XecErrors;;
open Parsing;;
open XecParser;;
open XecLexer;;
open Syntaxe;;
open Format;;

let lexemize_xec (inchannel) = (
	let lexbuf = Lexing.from_channel inchannel in
	let tk = ref (XecLexer.lexer lexbuf) in (
		while !tk <> TK_EOF do
			match (token_code !tk) with
			( co , lxm) -> (
				printf "line %3d col %2d to %2d : %15s = \"%s\"\n"
					lxm.line lxm.cstart lxm.cend  co lxm.str ;
			);
			tk := (XecLexer.lexer lexbuf)
		done
	)
)

let read_xec (inchannel) = (
	let lexbuf = Lexing.from_channel inchannel in
	try (
		XecParser.xecFile XecLexer.lexer lexbuf ;
	) with Parse_error -> (
		print_compile_error (Lexeme.last_made ()) "syntax error";
		exit 1
	)
)
