(* Note de Martin : J'ai ajout quelques "ignore" dans le code pour viter
 * tous les "usued variables" de Caml. *)

open Hashtbl
open XecErrors
open Lexeme
open Format

(*
Syntaxe (trs) abstraite:
on construit les tables de symboles directement a l'analyse

A LA FIN : utilitaires pour construire des val_exp
*)

(**********************************************)
(* Package : collection de tables de symboles *)
(**********************************************)
type package = {
	const_table : (string, const_info srcflaged) Hashtbl.t ;
	type_table  : (string, type_info srcflaged)  Hashtbl.t ;
	oper_table  : (string, oper_info srcflaged)  Hashtbl.t ;
	def_list    : def_item list ;
}
and
def_item =
   ConstDef of string  (** key in pk_const_table *)
|  TypeDef  of string  (** key in pk_type_table *)
|  OperDef  of string  (** key in pk_oper_table *)
(**************************************************)
(* Info associe  un identificateur de constante *)
(**************************************************)
and const_info = 
	ExternalConst  of (string * type_exp)
|	DefinedConst   of (string * type_exp option * val_exp)
(**************************************************)
(* Info associe  un identificateur de type *)
(**************************************************)
and type_info =
	ExternalType of (string)
|	AliasedType  of (string * type_exp)
|	EnumType     of (string * string list)
|	StructType   of (string * (string * type_exp) list)
(************************************************************)
(* Type "immdiat" : type les flots, params, constantes etc *) 
(************************************************************)
and type_exp =
	Bool
|	Int
|	Real
|	NamedType  of string 
|	ArrayType  of (type_exp * val_exp)
|	TupleType  of type_exp list
(*************************************************)
(* Info associe  un identificateur d'operateur *)
(*************************************************)
and oper_info = 
	FuncOper of func_info
|	NodeOper of node_info
(*************************************************)
(* Info associe  un identificateur de fonction *)
(*************************************************)
and func_info = {
	fi_name    : string ;
	fi_inpars  : (string * type_exp) list ;
	fi_outpars : (string * type_exp) list
}
(**********************************************)
(* Info associe  un identificateur de noeud *)
(**********************************************)
and equation = (left_part list * val_exp)
and flow_decl = (string * type_exp * clock_exp)
and node_info = {
	ni_name    :   string ;
	ni_inputs  :   flow_decl list ;
	ni_outputs :   flow_decl list ;
	ni_locals  :   flow_decl list ;
	ni_asserts :   val_exp list ;
	ni_defs    :   equation list
}
and clock_exp =
	BaseClock
|	NamedClock of string
and left_part = 
	LeftVar of string
|	LeftField of (string * string)
|	LeftArray of (string * val_exp)  
|	LeftSlice of (string * slice_info)
and slice_info = {
	first : val_exp ;
	last  : val_exp ;
	step  : val_exp option ;
}
(* Vision "fonctionnelle" des val_exp :
and val_exp = {
	exp_nature :	op_call;
	exp_operands : val_exp list;
}
*)
and val_exp = (op_call * operands)
and operands = Ops of val_exp list
(* Toutes les oprations classiques *)
and op_call =
(* zeroaire *)
	TRUE_n
|	FALSE_n
|	ICONST_n of string
|	RCONST_n of string
|	IVAL_n of int
|	RVAL_n of float
|	IDENT_n  of string
(* unaires *)
|	PRE_n
|	CURRENT_n
|	NOT_n
|	UMINUS_n
|	INT2REAL_n
|	REAL2INT_n
(* binaires *)
|	ARROW_n
|	WHEN_n
|	AND_n
|	OR_n
|	XOR_n
|	IMPL_n
|	EQ_n
|	NEQ_n
|	GTE_n
|	GT_n
|	LTE_n
|	LT_n
|	DIV_n
|	MOD_n
|	MINUS_n
|	PLUS_n
|	SLASH_n
|	TIMES_n
|	HAT_n
(* ternaires *)
|	IF_n
(* n-aires *)
|	NOR_n
|	DIESE_n
|	TUPLE_n
|	ARRAY_n
(* pseudo-unaire : appel par position *)
|	CALL_n of string
(* pseudo-unaire : FROM et TO (l'atg est un ident de type *)
|	FROM_n of string
|	TO_n of string
(* pseudo-unaire : acces tableau *)
|	ARRAY_ACCES_n of val_exp
|	ARRAY_SLICE_n of slice_info
(* pseudo-unaire : acces structure *)
|	STRUCT_ACCESS_n    of string
(* case entier : il doit y avoir le nombre de cas + 1 (default) *)
|	CASE_INT_n of (string * int list)
(* le select dans un tuple *)
(*  usage interne uniquement -> pas de syntaxe concrte *)
|	SELECT_n of int 


(******************************************************
UTILITAIRES :
	passage notation de constantes num <-> constantes num

N.B. : une notation flottante correcte
       doit tre invariante par : printf "%E" 
******************************************************)

let  int_of_ecint s = (
	let i = int_of_string s in
	let eci = sprintf "%d" i in
	let ii = int_of_string eci in
	if (i = ii) then i
	else raise (Global_error
		("(int_of_ecint) \""^s^"\" is not a valid numerical notation")
	)
) 

let  float_of_ecreal s = (
	let r = float_of_string s in
	let ecr = sprintf "%E" r in
	let rr = float_of_string ecr in
	if (r = rr) then r
	else raise (Global_error
		("(float_of_ecreal) \""^s^"\" is not a valid numerical notation")
	)
)

let ecint_of_int i = (
	let s = sprintf "%d" i in
	let ii = int_of_string s in
	if (i = ii) then s
	else raise (Global_error
		("(ecint_of_int) \""^s^"\" is not a valid numerical notation")
	)
) 

let ecreal_of_float r = (
	let s = sprintf "%E" r in
	let rr = float_of_string s in
	let eps = abs_float ( r -. rr ) in
	if (eps < 0.0001 ) then (
		if (eps <> 0.0) then (
			eprintf
			"Warning: round error of %E while converting internal value to \"%s\"\n"
			eps s
		) else (); 
		s
	) else raise (Global_error
		("(ecreal_of_float) \""^s^"\" is not a valid numerical notation")
	)
) 

(******************************************************
CONSTRUCTION DES val_exp
******************************************************)

(* cas gnral *)
let make_val_exp nat ops = (
	(nat, Ops ops)
   (*{ exp_nature = nat; exp_operands = ops }*)
)
(* constantes bool *)
let true_exp = (
	(TRUE_n, Ops [])
   (*{ exp_nature = TRUE_n; exp_operands = [] }*)
)
let false_exp = (
	(FALSE_n, Ops [])
   (*{ exp_nature = FALSE_n; exp_operands = [] }*)
)
(* constantes int *)
let int_exp (i : int) = (
	make_val_exp (ICONST_n (ecint_of_int i)) []
)
(* ident  *)
let ident_exp (s : string) = (
	make_val_exp (IDENT_n s) []
)

let exp_nat = (function (x, Ops _) -> x)
let exp_ops = (function (_, Ops y) -> y)


(* UTILITAIRE : fabrication d'une table de def de var *)

let make_def_table : package -> node_info -> (string, val_exp) Hashtbl.t =
function p -> ignore p; function n -> (
	let tab = Hashtbl.create 50 in
	let treat_equation (eq : equation) = (
		match eq with ([LeftVar id], exp) -> (
			Hashtbl.add tab id exp
		) |  (lpl, exp) -> (
			(* on accepte les liste d'idents simples *)
			let rec treat_id accin lp = (
				match lp with 
				LeftVar id -> (
					let projexp = make_val_exp (SELECT_n accin) [ exp ] in
					Hashtbl.add tab id projexp ;
					accin+1
				) | _ -> raise (
					Internal_error("make_def_table::treat_equation","not implemented")
				)
			) in
			let _ = List.fold_left treat_id 0 lpl in () 
		)
	) in
	List.iter treat_equation n.ni_defs ;
	tab
) 
