(*

Typage ET clockage des expressions Lustre
-----------------------------------------
On prend AUSSI en charge le calcul des expressions constantes !!!

- Le type "t" dnote l'objet smantique "type"
- La compatibilit des types se fait sur l'galit des "type_eff"
- Il n'y a pas de type_eff "tuple" !

- La fonction principale est :
  Typing.exp_type : Typing.env -> Syntaxe.val_exp -> Typing.type_eff list

- Le calcul des constantes :
  Typing.eval_const_exp : Typing.env -> Syntaxe.val_exp -> Typing.const
  Typing.eval_const_int : Typing.env -> Syntaxe.val_exp -> int 

- Un typing_env est un OBJET IMPERATIF construit
  a partir d'un package et d'un noeud :
  Typing.get_env : Syntaxe.package -> Syntaxe.node_info -> Typing.env
*)

(************  type_eff *********************)
(*-------------------------------------------
	Un type_eff passe  travers les aliases :
	Il implmente de fait l'quivalence entre
	type, et donc le type-checking.	
---------------------------------------------*)
type type_eff =
	TE_bool
|	TE_int
|	TE_real
|	TE_extern of string
|	TE_enum of (string * string list)
|	TE_struct of (string * (string * type_eff) list)
|	TE_array of (type_eff * int)

(************  utilitaires *********************)
(*----------------------------------------------
	Passage string <-> type_eff
	pour l'affichage/deboguage
----------------------------------------------*)
val string_of_type_eff : type_eff -> string
val string_of_type_eff_list : type_eff list -> string


(****  env (type abstrait principal) *************)
(*----------------------------------------------
Toutes les manips passent par la
cration/manipulation/interrogation de 
cet objet
----------------------------------------------*)
type env

(* 
	Cration d'un environnement  partir d'un 
	package (pour les types et constantes)
	et d'un noeud optionnel (pour les flots)
*)
val get_env : Syntaxe.package -> Syntaxe.node_info option -> env

(*
	un environnent vide : NE PAS MODIFIER !
*)
val empty_env : env

(*
	Ajout d'une dclaration de flow dans l'env
DANS L'ORDRE : type, clock, id
*)

val declare_flow : env -> type_eff -> Syntaxe.clock_exp -> string -> unit

(*****************************)
(* LES FONCTIONS PRINCIPALES *)
(*****************************)

(* utilititaire : type_exp quivalente  un type_eff *)
val type_exp_of_type_eff : env -> type_eff -> Syntaxe.type_exp

(* typage d'une expression => une liste dans le cas gnral *)
val exp_type : env -> Syntaxe.val_exp -> type_eff list
val ident_type : env -> string -> type_eff

(* clockage d'une expression => restriction au mon-clock ! *)
val exp_clock : env -> Syntaxe.val_exp -> Syntaxe.clock_exp
val ident_clock : env -> string -> Syntaxe.clock_exp


(* Iteration sur l'ensemble des types nomms *)

val iter_on_types : env -> (string -> type_eff -> unit) -> unit
