# 1 "src/xec/xecLexer.mll"
 

(*
la gestion des no de ligne est faite dans Lexeme 
pour viter les dpendances boucles entre Lexer et Parser
*)
open Lexeme
open XecParser
open Lexing
open Hashtbl

(* rcupration d'erreur avec correction line/col *)
exception Lexical_error of string * int * int

let handle_lexical_error fn lexbuf = (
   let lxm = Lexeme.make (lexbuf ) in
   try
      fn lexbuf
   with Lexical_error(msg, _, _) ->
      raise(Lexical_error(msg, lxm.line, lxm.cstart))
)

(* table des mots-cl *)
let keywords = Hashtbl.create 50 ;;
Hashtbl.add keywords "and"       (function s -> TK_AND s) ;;
Hashtbl.add keywords "assert"    (function s -> TK_ASSERT s) ;;
Hashtbl.add keywords "bool"      (function s -> TK_BOOL s) ;;
Hashtbl.add keywords "const"     (function s -> TK_CONST s) ;;
Hashtbl.add keywords "current"   (function s -> TK_CURRENT s) ;;
Hashtbl.add keywords "div"       (function s -> TK_DIV s) ;;
Hashtbl.add keywords "else"      (function s -> TK_ELSE s) ;;
Hashtbl.add keywords "enum"      (function s -> TK_ENUM s) ;;
Hashtbl.add keywords "equa"      (function s -> TK_EQUA s) ;;
Hashtbl.add keywords "false"     (function s -> TK_FALSE s) ;;
Hashtbl.add keywords "if"        (function s -> TK_IF s) ;;
Hashtbl.add keywords "int"       (function s -> TK_INT s) ;;
Hashtbl.add keywords "let"       (function s -> TK_LET s) ;;
Hashtbl.add keywords "mod"       (function s -> TK_MOD s) ;;
Hashtbl.add keywords "node"      (function s -> TK_NODE s) ;;
Hashtbl.add keywords "function"  (function s -> TK_FUNCTION s) ;;
Hashtbl.add keywords "not"       (function s -> TK_NOT s) ;;
Hashtbl.add keywords "or"        (function s -> TK_OR s) ;;
Hashtbl.add keywords "nor"       (function s -> TK_NOR s) ;;
Hashtbl.add keywords "pre"       (function s -> TK_PRE s) ;;
Hashtbl.add keywords "real"      (function s -> TK_REAL s) ;;
Hashtbl.add keywords "returns"   (function s -> TK_RETURNS s) ;;
Hashtbl.add keywords "tel"       (function s -> TK_TEL s) ;;
Hashtbl.add keywords "type"      (function s -> TK_TYPE s) ;;
Hashtbl.add keywords "then"      (function s -> TK_THEN s) ;;
Hashtbl.add keywords "true"      (function s -> TK_TRUE s) ;;
Hashtbl.add keywords "var"       (function s -> TK_VAR s) ;;
Hashtbl.add keywords "when"      (function s -> TK_WHEN s) ;;
Hashtbl.add keywords "xor"       (function s -> TK_XOR s) ;;
Hashtbl.add keywords "of"       (function s -> TK_OF s) ;;

let is_a_keyword ( s: string ) = (
	try
		let res = Hashtbl.find keywords s in (Some res)
	with Not_found -> ( None )
)

let token_code tk = (
	match tk with
		  TK_EOF          -> ( "TK_EOF" , Lexeme.dummy)
		| TK_ERROR    lxm -> ( "TK_ERROR" , lxm )
		| TK_AND      lxm -> ( "TK_AND" , lxm )
		| TK_ARROW    lxm -> ( "TK_ARROW" , lxm )
		| TK_ASSERT   lxm -> ( "TK_ASSERT" , lxm )
		| TK_BAR      lxm -> ( "TK_BAR" , lxm )
		| TK_BOOL     lxm -> ( "TK_BOOL" , lxm )
		| TK_CDOTS    lxm -> ( "TK_CDOTS" , lxm )
		| TK_CLOSE_BRACKET lxm -> ( "TK_CLOSE_BRACKET" , lxm )
		| TK_CLOSE_BRACE   lxm -> ( "TK_CLOSE_BRACE" , lxm )
		| TK_CLOSE_PAR     lxm -> ( "TK_CLOSE_PAR" , lxm )
		| TK_COLON    lxm -> ( "TK_COLON" , lxm )
		| TK_COMA     lxm -> ( "TK_COMA" , lxm )
		| TK_CONST    lxm -> ( "TK_CONST" , lxm )
		| TK_CURRENT  lxm -> ( "TK_CURRENT" , lxm )
		| TK_DIESE    lxm -> ( "TK_DIESE" , lxm )
		| TK_DIV      lxm -> ( "TK_DIV" , lxm )
		| TK_DOT      lxm -> ( "TK_DOT" , lxm )
		| TK_ELSE     lxm -> ( "TK_ELSE" , lxm )
		| TK_EQ       lxm -> ( "TK_EQ" , lxm )
		| TK_EQUA     lxm -> ( "TK_EQUA" , lxm )
		| TK_ENUM     lxm -> ( "TK_ENUM" , lxm )
		| TK_FALSE    lxm -> ( "TK_FALSE" , lxm )
		| TK_FUNCTION lxm -> ( "TK_FUNCTION" , lxm )
		| TK_FIELD    lxm -> ( "TK_FIELD" , lxm )
		| TK_GT       lxm -> ( "TK_GT" , lxm )
		| TK_GTE      lxm -> ( "TK_GTE" , lxm )
		| TK_HAT      lxm -> ( "TK_HAT" , lxm )
		| TK_ICONST   lxm -> ( "TK_ICONST" , lxm )
		| TK_IDENT    lxm -> ( "TK_IDENT" , lxm )
		| TK_IF       lxm -> ( "TK_IF" , lxm )
		| TK_IMPL     lxm -> ( "TK_IMPL" , lxm )
		| TK_INT      lxm -> ( "TK_INT" , lxm )
		| TK_LET      lxm -> ( "TK_LET" , lxm )
		| TK_LT       lxm -> ( "TK_LT" , lxm )
		| TK_LTE      lxm -> ( "TK_LTE" , lxm )
		| TK_MINUS    lxm -> ( "TK_MINUS" , lxm )
		| TK_MOD      lxm -> ( "TK_MOD" , lxm )
		| TK_NEQ      lxm -> ( "TK_NEQ" , lxm )
		| TK_NODE     lxm -> ( "TK_NODE" , lxm )
		| TK_NOR      lxm -> ( "TK_NOR" , lxm )
		| TK_NOT      lxm -> ( "TK_NOT" , lxm )
		| TK_OPEN_BRACKET lxm -> ( "TK_OPEN_BRACKET" , lxm )
		| TK_OPEN_BRACE   lxm -> ( "TK_OPEN_BRACE" , lxm )
		| TK_OPEN_PAR lxm -> ( "TK_OPEN_PAR" , lxm )
		| TK_OR       lxm -> ( "TK_OR" , lxm )
		| TK_PCENT    lxm -> ( "TK_PCENT" , lxm )
		| TK_PLUS     lxm -> ( "TK_PLUS" , lxm )
		| TK_PRE      lxm -> ( "TK_PRE" , lxm )
		| TK_RCONST   lxm -> ( "TK_RCONST" , lxm )
		| TK_REAL     lxm -> ( "TK_REAL" , lxm )
		| TK_RETURNS  lxm -> ( "TK_RETURNS" , lxm )
		| TK_SEMICOL  lxm -> ( "TK_SEMICOL" , lxm )
		| TK_STAR     lxm -> ( "TK_STAR" , lxm )
		| TK_SLASH    lxm -> ( "TK_SLASH" , lxm )
		| TK_TEL      lxm -> ( "TK_TEL" , lxm )
		| TK_THEN     lxm -> ( "TK_THEN" , lxm )
		| TK_TRUE     lxm -> ( "TK_TRUE" , lxm )
		| TK_TYPE     lxm -> ( "TK_TYPE" , lxm )
		| TK_VAR      lxm -> ( "TK_VAR" , lxm )
		| TK_WHEN     lxm -> ( "TK_WHEN" , lxm )
		| TK_XOR lxm -> ( "TK_XOR" , lxm )
		| TK_OF lxm -> ( "TK_OF" , lxm )
)


# 132 "src/xec/xecLexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\217\255\078\000\221\255\222\255\223\255\224\255\225\255\
    \227\255\228\255\229\255\231\255\233\255\234\255\236\255\237\255\
    \238\255\002\000\075\000\002\000\164\000\176\000\161\000\050\000\
    \253\255\002\000\255\255\252\255\246\255\251\255\186\000\209\000\
    \219\000\240\000\255\000\009\001\019\001\240\255\241\255\029\001\
    \051\001\061\001\071\001\245\255\243\255\244\255\242\255\129\000\
    \254\255\055\000\023\000";
  Lexing.lex_backtrk = 
   "\255\255\255\255\037\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\036\000\035\000\023\000\025\000\005\000\016\000\029\000\
    \255\255\001\000\255\255\255\255\255\255\255\255\007\000\255\255\
    \006\000\255\255\255\255\007\000\255\255\255\255\255\255\008\000\
    \255\255\008\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\255\255\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\255\255\
    \255\255\255\255\255\255\000\000\000\000\000\000\000\000\027\000\
    \000\000\255\255\024\000";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\025\000\024\000\025\000\000\000\025\000\000\000\025\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \025\000\026\000\025\000\011\000\000\000\000\000\000\000\000\000\
    \023\000\007\000\013\000\015\000\010\000\022\000\020\000\014\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\008\000\009\000\018\000\019\000\017\000\046\000\
    \043\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\004\000\027\000\003\000\016\000\002\000\
    \026\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\006\000\012\000\005\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \045\000\044\000\000\000\048\000\000\000\000\000\000\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\000\000\000\000\049\000\000\000\002\000\000\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\038\000\000\000\000\000\000\000\000\000\029\000\000\000\
    \000\000\000\000\037\000\000\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\030\000\028\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\000\000\031\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\033\000\000\000\033\000\034\000\
    \026\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\031\000\000\000\048\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\034\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\036\000\000\000\036\000\000\000\000\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\042\000\000\000\
    \042\000\000\000\040\000\041\000\041\000\041\000\041\000\041\000\
    \041\000\041\000\041\000\041\000\041\000\041\000\041\000\041\000\
    \041\000\041\000\041\000\041\000\041\000\041\000\041\000\041\000\
    \041\000\041\000\041\000\041\000\041\000\041\000\041\000\041\000\
    \041\000\024\000\040\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\025\000\255\255\000\000\255\255\025\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\050\000\025\000\000\000\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\017\000\
    \019\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\023\000\000\000\000\000\000\000\
    \049\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \018\000\018\000\255\255\047\000\255\255\255\255\255\255\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\255\255\255\255\047\000\255\255\002\000\255\255\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\020\000\255\255\255\255\255\255\255\255\022\000\255\255\
    \255\255\255\255\020\000\255\255\020\000\020\000\020\000\020\000\
    \020\000\020\000\020\000\020\000\020\000\020\000\021\000\022\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\255\255\021\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\031\000\255\255\031\000\030\000\
    \000\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\021\000\255\255\050\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\030\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\034\000\255\255\034\000\255\255\255\255\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\040\000\255\255\
    \040\000\255\255\039\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\041\000\041\000\041\000\
    \041\000\041\000\041\000\041\000\041\000\041\000\041\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\047\000\039\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec lexer lexbuf =
    __ocaml_lex_lexer_rec lexbuf 0
and __ocaml_lex_lexer_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 138 "src/xec/xecLexer.mll"
  ( TK_EOF )
# 329 "src/xec/xecLexer.ml"

  | 1 ->
# 141 "src/xec/xecLexer.mll"
  ( lexer lexbuf )
# 334 "src/xec/xecLexer.ml"

  | 2 ->
# 144 "src/xec/xecLexer.mll"
  (
			Lexeme.new_line ( lexbuf );
			lexer lexbuf	
		)
# 342 "src/xec/xecLexer.ml"

  | 3 ->
# 150 "src/xec/xecLexer.mll"
  (
			handle_lexical_error comment_par lexbuf;
			lexer lexbuf
		)
# 350 "src/xec/xecLexer.ml"

  | 4 ->
# 156 "src/xec/xecLexer.mll"
  (
			handle_lexical_error comment_line lexbuf;
			lexer lexbuf
		)
# 358 "src/xec/xecLexer.ml"

  | 5 ->
# 161 "src/xec/xecLexer.mll"
                ( TK_ICONST (Lexeme.make lexbuf ) )
# 363 "src/xec/xecLexer.ml"

  | 6 ->
# 163 "src/xec/xecLexer.mll"
                          ( TK_RCONST (Lexeme.make lexbuf ) )
# 368 "src/xec/xecLexer.ml"

  | 7 ->
# 165 "src/xec/xecLexer.mll"
                                           ( TK_RCONST (Lexeme.make lexbuf ) )
# 373 "src/xec/xecLexer.ml"

  | 8 ->
# 167 "src/xec/xecLexer.mll"
                               ( TK_RCONST (Lexeme.make lexbuf ) )
# 378 "src/xec/xecLexer.ml"

  | 9 ->
# 170 "src/xec/xecLexer.mll"
        ( TK_ARROW ( Lexeme.make lexbuf ) )
# 383 "src/xec/xecLexer.ml"

  | 10 ->
# 171 "src/xec/xecLexer.mll"
        ( TK_IMPL ( Lexeme.make lexbuf ) )
# 388 "src/xec/xecLexer.ml"

  | 11 ->
# 172 "src/xec/xecLexer.mll"
        ( TK_LTE ( Lexeme.make lexbuf ) )
# 393 "src/xec/xecLexer.ml"

  | 12 ->
# 173 "src/xec/xecLexer.mll"
        ( TK_NEQ ( Lexeme.make lexbuf ) )
# 398 "src/xec/xecLexer.ml"

  | 13 ->
# 174 "src/xec/xecLexer.mll"
        ( TK_GTE ( Lexeme.make lexbuf ) )
# 403 "src/xec/xecLexer.ml"

  | 14 ->
# 175 "src/xec/xecLexer.mll"
        ( TK_FIELD ( Lexeme.make lexbuf ) )
# 408 "src/xec/xecLexer.ml"

  | 15 ->
# 176 "src/xec/xecLexer.mll"
        ( TK_CDOTS ( Lexeme.make lexbuf ) )
# 413 "src/xec/xecLexer.ml"

  | 16 ->
# 178 "src/xec/xecLexer.mll"
        ( TK_MINUS ( Lexeme.make lexbuf ) )
# 418 "src/xec/xecLexer.ml"

  | 17 ->
# 179 "src/xec/xecLexer.mll"
        ( TK_HAT ( Lexeme.make lexbuf ) )
# 423 "src/xec/xecLexer.ml"

  | 18 ->
# 180 "src/xec/xecLexer.mll"
        ( TK_PLUS ( Lexeme.make lexbuf ) )
# 428 "src/xec/xecLexer.ml"

  | 19 ->
# 181 "src/xec/xecLexer.mll"
        ( TK_SLASH ( Lexeme.make lexbuf ) )
# 433 "src/xec/xecLexer.ml"

  | 20 ->
# 182 "src/xec/xecLexer.mll"
        ( TK_PCENT ( Lexeme.make lexbuf ) )
# 438 "src/xec/xecLexer.ml"

  | 21 ->
# 183 "src/xec/xecLexer.mll"
        ( TK_STAR ( Lexeme.make lexbuf ) )
# 443 "src/xec/xecLexer.ml"

  | 22 ->
# 184 "src/xec/xecLexer.mll"
        ( TK_BAR ( Lexeme.make lexbuf ) )
# 448 "src/xec/xecLexer.ml"

  | 23 ->
# 185 "src/xec/xecLexer.mll"
        ( TK_EQ ( Lexeme.make lexbuf ) )
# 453 "src/xec/xecLexer.ml"

  | 24 ->
# 186 "src/xec/xecLexer.mll"
        ( TK_DIESE ( Lexeme.make lexbuf ) )
# 458 "src/xec/xecLexer.ml"

  | 25 ->
# 188 "src/xec/xecLexer.mll"
        ( TK_DOT ( Lexeme.make lexbuf ) )
# 463 "src/xec/xecLexer.ml"

  | 26 ->
# 189 "src/xec/xecLexer.mll"
        ( TK_COMA ( Lexeme.make lexbuf ) )
# 468 "src/xec/xecLexer.ml"

  | 27 ->
# 190 "src/xec/xecLexer.mll"
        ( TK_SEMICOL ( Lexeme.make lexbuf ) )
# 473 "src/xec/xecLexer.ml"

  | 28 ->
# 191 "src/xec/xecLexer.mll"
        ( TK_COLON ( Lexeme.make lexbuf ) )
# 478 "src/xec/xecLexer.ml"

  | 29 ->
# 192 "src/xec/xecLexer.mll"
        ( TK_OPEN_PAR ( Lexeme.make lexbuf ) )
# 483 "src/xec/xecLexer.ml"

  | 30 ->
# 193 "src/xec/xecLexer.mll"
        ( TK_CLOSE_PAR ( Lexeme.make lexbuf ) )
# 488 "src/xec/xecLexer.ml"

  | 31 ->
# 194 "src/xec/xecLexer.mll"
        ( TK_OPEN_BRACE ( Lexeme.make lexbuf ) )
# 493 "src/xec/xecLexer.ml"

  | 32 ->
# 195 "src/xec/xecLexer.mll"
        ( TK_CLOSE_BRACE ( Lexeme.make lexbuf ) )
# 498 "src/xec/xecLexer.ml"

  | 33 ->
# 196 "src/xec/xecLexer.mll"
        ( TK_OPEN_BRACKET ( Lexeme.make lexbuf ) )
# 503 "src/xec/xecLexer.ml"

  | 34 ->
# 197 "src/xec/xecLexer.mll"
        ( TK_CLOSE_BRACKET ( Lexeme.make lexbuf ) )
# 508 "src/xec/xecLexer.ml"

  | 35 ->
# 198 "src/xec/xecLexer.mll"
        ( TK_LT ( Lexeme.make lexbuf ) )
# 513 "src/xec/xecLexer.ml"

  | 36 ->
# 199 "src/xec/xecLexer.mll"
        ( TK_GT ( Lexeme.make lexbuf ) )
# 518 "src/xec/xecLexer.ml"

  | 37 ->
# 202 "src/xec/xecLexer.mll"
  (
			let lxm = Lexeme.make lexbuf in
			let x = is_a_keyword ( lxm.str ) in
			match x with
				  None -> TK_IDENT ( lxm )
				| Some keyw -> keyw (lxm )
		)
# 529 "src/xec/xecLexer.ml"

  | 38 ->
# 209 "src/xec/xecLexer.mll"
        ( TK_ERROR ( Lexeme.make lexbuf ) )
# 534 "src/xec/xecLexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_lexer_rec lexbuf __ocaml_lex_state

and comment_par lexbuf =
    __ocaml_lex_comment_par_rec lexbuf 47
and __ocaml_lex_comment_par_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 213 "src/xec/xecLexer.mll"
  ( )
# 545 "src/xec/xecLexer.ml"

  | 1 ->
# 215 "src/xec/xecLexer.mll"
  (
			Lexeme.new_line ( lexbuf );
			comment_par lexbuf	
		)
# 553 "src/xec/xecLexer.ml"

  | 2 ->
# 220 "src/xec/xecLexer.mll"
  (
			raise(Lexical_error("unterminated comment", 0, 0))
		)
# 560 "src/xec/xecLexer.ml"

  | 3 ->
# 224 "src/xec/xecLexer.mll"
  ( comment_par lexbuf )
# 565 "src/xec/xecLexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_par_rec lexbuf __ocaml_lex_state

and comment_line lexbuf =
    __ocaml_lex_comment_line_rec lexbuf 50
and __ocaml_lex_comment_line_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 228 "src/xec/xecLexer.mll"
  (
			Lexeme.new_line ( lexbuf );
		)
# 578 "src/xec/xecLexer.ml"

  | 1 ->
# 232 "src/xec/xecLexer.mll"
  ( )
# 583 "src/xec/xecLexer.ml"

  | 2 ->
# 234 "src/xec/xecLexer.mll"
  ( comment_line lexbuf )
# 588 "src/xec/xecLexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_line_rec lexbuf __ocaml_lex_state

;;

