type token =
  | TK_EOF
  | TK_ERROR of (Lexeme.t)
  | TK_AND of (Lexeme.t)
  | TK_ARROW of (Lexeme.t)
  | TK_ASSERT of (Lexeme.t)
  | TK_BAR of (Lexeme.t)
  | TK_BOOL of (Lexeme.t)
  | TK_CDOTS of (Lexeme.t)
  | TK_CLOSE_BRACE of (Lexeme.t)
  | TK_CLOSE_BRACKET of (Lexeme.t)
  | TK_CLOSE_PAR of (Lexeme.t)
  | TK_COLON of (Lexeme.t)
  | TK_COMA of (Lexeme.t)
  | TK_CONST of (Lexeme.t)
  | TK_CURRENT of (Lexeme.t)
  | TK_DIESE of (Lexeme.t)
  | TK_DIV of (Lexeme.t)
  | TK_DOT of (Lexeme.t)
  | TK_EQ of (Lexeme.t)
  | TK_EQUA of (Lexeme.t)
  | TK_ELSE of (Lexeme.t)
  | TK_ENUM of (Lexeme.t)
  | TK_FALSE of (Lexeme.t)
  | TK_FIELD of (Lexeme.t)
  | TK_FUNCTION of (Lexeme.t)
  | TK_GT of (Lexeme.t)
  | TK_GTE of (Lexeme.t)
  | TK_HAT of (Lexeme.t)
  | TK_ICONST of (Lexeme.t)
  | TK_IDENT of (Lexeme.t)
  | TK_IF of (Lexeme.t)
  | TK_IMPL of (Lexeme.t)
  | TK_INT of (Lexeme.t)
  | TK_LET of (Lexeme.t)
  | TK_LT of (Lexeme.t)
  | TK_LTE of (Lexeme.t)
  | TK_MINUS of (Lexeme.t)
  | TK_MOD of (Lexeme.t)
  | TK_NEQ of (Lexeme.t)
  | TK_NODE of (Lexeme.t)
  | TK_NOR of (Lexeme.t)
  | TK_NOT of (Lexeme.t)
  | TK_OPEN_BRACE of (Lexeme.t)
  | TK_OPEN_BRACKET of (Lexeme.t)
  | TK_OPEN_PAR of (Lexeme.t)
  | TK_OR of (Lexeme.t)
  | TK_PCENT of (Lexeme.t)
  | TK_PLUS of (Lexeme.t)
  | TK_PRE of (Lexeme.t)
  | TK_RCONST of (Lexeme.t)
  | TK_REAL of (Lexeme.t)
  | TK_RETURNS of (Lexeme.t)
  | TK_SEMICOL of (Lexeme.t)
  | TK_SLASH of (Lexeme.t)
  | TK_STAR of (Lexeme.t)
  | TK_TEL of (Lexeme.t)
  | TK_THEN of (Lexeme.t)
  | TK_TRUE of (Lexeme.t)
  | TK_TYPE of (Lexeme.t)
  | TK_VAR of (Lexeme.t)
  | TK_WHEN of (Lexeme.t)
  | TK_XOR of (Lexeme.t)
  | TK_OF of (Lexeme.t)

open Parsing;;
# 2 "src/xec/xecParser.mly"
(*----------------------------------------------------------------
Passage xec -> format interne

xec = extented expanded code = lustre core
----------------------------------------------------------------*)
open Lexing
open Lexeme
open Syntaxe
open XecErrors
open Format
open Str

(* init parse *)
let const_table = ref (Hashtbl.create 50)
let type_table  = ref (Hashtbl.create 50)
let oper_table  = ref (Hashtbl.create 50)
let def_list    = ref []

let add_info
   (htbl   : (string, 'a srcflaged) Hashtbl.t)
   (kindof : string)   (* une string en cas d'erreur   *)
   (lxm  : Lexeme.t)   (* le lexeme en question        *)
   (info : 'a)         (* l'info en question           *)
= (
   try
      let x  = Hashtbl.find htbl lxm.str in
      raise (
         Compile_error ( lxm ,
            (sprintf "bad %s declaration, ident already linked line %d col %d"
               kindof x.src.line x.src.cstart)
         )
      )
   with Not_found -> (
      Hashtbl.add htbl lxm.str {
         src = lxm ;
         it  = info
      }
   )
)

let add_constant (lxm : Lexeme.t) (ci : const_info) = (
	add_info !const_table "constant" lxm ci ;
	def_list := (ConstDef lxm.str) :: !def_list
) 
let add_type (lxm : Lexeme.t) (ci : type_info) = (
	add_info !type_table "type" lxm ci;
	def_list := (TypeDef lxm.str) :: !def_list
)
let add_oper (lxm : Lexeme.t) (ci : oper_info) = (
	add_info !oper_table "operator" lxm ci;
	def_list := (OperDef lxm.str) :: !def_list
)

(* Utilitaire : cre un tripet (var, type, clock) *)
let add_type_n_clock_to_var ty ck var = (var, ty, ck)

let add_type_to_var ty var = (var, ty)

# 127 "src/xec/xecParser.ml"
let yytransl_const = [|
  257 (* TK_EOF *);
    0|]

let yytransl_block = [|
  258 (* TK_ERROR *);
  259 (* TK_AND *);
  260 (* TK_ARROW *);
  261 (* TK_ASSERT *);
  262 (* TK_BAR *);
  263 (* TK_BOOL *);
  264 (* TK_CDOTS *);
  265 (* TK_CLOSE_BRACE *);
  266 (* TK_CLOSE_BRACKET *);
  267 (* TK_CLOSE_PAR *);
  268 (* TK_COLON *);
  269 (* TK_COMA *);
  270 (* TK_CONST *);
  271 (* TK_CURRENT *);
  272 (* TK_DIESE *);
  273 (* TK_DIV *);
  274 (* TK_DOT *);
  275 (* TK_EQ *);
  276 (* TK_EQUA *);
  277 (* TK_ELSE *);
  278 (* TK_ENUM *);
  279 (* TK_FALSE *);
  280 (* TK_FIELD *);
  281 (* TK_FUNCTION *);
  282 (* TK_GT *);
  283 (* TK_GTE *);
  284 (* TK_HAT *);
  285 (* TK_ICONST *);
  286 (* TK_IDENT *);
  287 (* TK_IF *);
  288 (* TK_IMPL *);
  289 (* TK_INT *);
  290 (* TK_LET *);
  291 (* TK_LT *);
  292 (* TK_LTE *);
  293 (* TK_MINUS *);
  294 (* TK_MOD *);
  295 (* TK_NEQ *);
  296 (* TK_NODE *);
  297 (* TK_NOR *);
  298 (* TK_NOT *);
  299 (* TK_OPEN_BRACE *);
  300 (* TK_OPEN_BRACKET *);
  301 (* TK_OPEN_PAR *);
  302 (* TK_OR *);
  303 (* TK_PCENT *);
  304 (* TK_PLUS *);
  305 (* TK_PRE *);
  306 (* TK_RCONST *);
  307 (* TK_REAL *);
  308 (* TK_RETURNS *);
  309 (* TK_SEMICOL *);
  310 (* TK_SLASH *);
  311 (* TK_STAR *);
  312 (* TK_TEL *);
  313 (* TK_THEN *);
  314 (* TK_TRUE *);
  315 (* TK_TYPE *);
  316 (* TK_VAR *);
  317 (* TK_WHEN *);
  318 (* TK_XOR *);
  319 (* TK_OF *);
    0|]

let yylhs = "\255\255\
\001\000\001\000\002\000\002\000\003\000\003\000\003\000\003\000\
\008\000\009\000\009\000\010\000\012\000\012\000\004\000\004\000\
\013\000\013\000\014\000\005\000\005\000\015\000\015\000\016\000\
\011\000\011\000\017\000\017\000\017\000\006\000\007\000\019\000\
\019\000\022\000\022\000\022\000\020\000\020\000\020\000\021\000\
\018\000\018\000\018\000\023\000\023\000\024\000\024\000\026\000\
\026\000\027\000\027\000\028\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\030\000\030\000\030\000\030\000\
\030\000\030\000\031\000\031\000\031\000\031\000\031\000\031\000\
\031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
\031\000\031\000\031\000\031\000\032\000\032\000\029\000\029\000\
\029\000\029\000\033\000\033\000\000\000"

let yylen = "\002\000\
\001\000\002\000\001\000\002\000\001\000\001\000\001\000\001\000\
\001\000\001\000\003\000\003\000\001\000\003\000\003\000\003\000\
\001\000\003\000\003\000\003\000\003\000\001\000\003\000\001\000\
\001\000\001\000\001\000\001\000\001\000\010\000\012\000\001\000\
\003\000\001\000\003\000\005\000\000\000\002\000\003\000\004\000\
\000\000\001\000\001\000\001\000\002\000\003\000\004\000\001\000\
\003\000\001\000\003\000\001\000\001\000\001\000\001\000\001\000\
\006\000\001\000\004\000\003\000\002\000\002\000\002\000\002\000\
\002\000\002\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\004\000\003\000\001\000\001\000\
\001\000\001\000\001\000\003\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\001\000\000\000\000\000\000\000\000\000\093\000\
\000\000\003\000\005\000\006\000\007\000\008\000\009\000\000\000\
\000\000\017\000\000\000\000\000\024\000\000\000\022\000\002\000\
\004\000\000\000\016\000\000\000\000\000\000\000\000\000\021\000\
\020\000\027\000\028\000\029\000\026\000\019\000\025\000\018\000\
\010\000\000\000\013\000\000\000\000\000\000\000\000\000\032\000\
\023\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\012\000\011\000\000\000\014\000\000\000\035\000\000\000\
\033\000\000\000\000\000\000\000\000\000\036\000\000\000\000\000\
\000\000\043\000\042\000\030\000\000\000\000\000\000\000\038\000\
\000\000\000\000\031\000\000\000\000\000\000\000\052\000\000\000\
\044\000\000\000\000\000\050\000\000\000\000\000\088\000\089\000\
\000\000\000\000\000\000\000\000\000\000\000\000\090\000\000\000\
\087\000\000\000\000\000\053\000\055\000\056\000\058\000\000\000\
\000\000\045\000\000\000\000\000\064\000\000\000\000\000\065\000\
\062\000\000\000\000\000\000\000\063\000\066\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\046\000\000\000\000\000\
\000\000\000\000\049\000\040\000\000\000\051\000\000\000\000\000\
\060\000\000\000\086\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\068\000\000\000\047\000\059\000\
\000\000\000\000\085\000\000\000\000\000"

let yydgoto = "\002\000\
\008\000\009\000\010\000\011\000\012\000\013\000\014\000\106\000\
\042\000\046\000\038\000\044\000\017\000\018\000\022\000\023\000\
\039\000\076\000\047\000\079\000\083\000\048\000\088\000\089\000\
\123\000\090\000\091\000\092\000\108\000\109\000\110\000\111\000\
\124\000"

let yysindex = "\017\000\
\018\255\000\000\000\000\001\255\001\255\001\255\001\255\000\000\
\020\255\000\000\000\000\000\000\000\000\000\000\000\000\024\255\
\243\254\000\000\031\255\054\255\000\000\247\254\000\000\000\000\
\000\000\179\255\000\000\001\255\001\255\240\254\001\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\255\000\000\012\255\001\255\006\255\017\255\000\000\
\000\000\179\255\001\255\053\255\001\255\106\255\001\255\066\255\
\240\254\000\000\000\000\098\255\000\000\083\255\000\000\109\255\
\000\000\001\255\001\255\240\254\028\255\000\000\057\255\051\255\
\117\255\000\000\000\000\000\000\102\255\241\254\138\255\000\000\
\118\255\122\255\000\000\240\254\044\002\001\255\000\000\211\000\
\000\000\154\255\162\255\000\000\044\002\131\255\000\000\000\000\
\044\002\044\002\044\002\044\002\044\002\044\002\000\000\044\002\
\000\000\144\255\042\000\000\000\000\000\000\000\000\000\022\255\
\051\255\000\000\044\002\001\255\000\000\044\002\081\000\000\000\
\000\000\009\002\198\000\112\255\000\000\000\000\246\001\044\002\
\044\002\044\002\044\002\044\002\044\002\044\002\044\002\044\002\
\044\002\044\002\044\002\044\002\044\002\000\000\044\002\044\002\
\044\002\044\002\000\000\000\000\120\000\000\000\115\255\044\002\
\000\000\044\002\000\000\120\255\017\002\047\001\121\255\009\002\
\009\002\009\002\009\002\009\002\009\002\226\000\121\255\009\002\
\211\001\226\000\121\255\121\255\000\000\211\001\000\000\000\000\
\159\000\198\000\000\000\044\002\198\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\107\255\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\060\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\030\000\
\000\000\000\000\000\000\000\000\153\255\000\000\000\000\000\000\
\000\000\000\000\000\000\157\255\000\000\000\000\000\000\000\000\
\000\000\000\000\164\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\103\255\000\000\000\000\000\000\000\000\000\000\000\000\
\030\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\085\001\123\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\088\000\062\255\142\255\166\000\
\057\001\112\001\124\001\146\001\169\001\236\000\181\255\172\001\
\086\001\019\001\220\255\003\000\000\000\198\001\000\000\000\000\
\000\000\137\255\000\000\000\000\251\254"

let yygindex = "\000\000\
\000\000\000\000\184\000\000\000\000\000\000\000\000\000\252\255\
\000\000\247\001\151\000\137\000\000\000\177\000\000\000\175\000\
\000\000\097\000\195\255\000\000\000\000\209\255\000\000\123\000\
\213\255\000\000\128\000\099\000\000\000\000\000\000\000\000\000\
\149\255"

let yytablesize = 870
let yytable = "\016\000\
\019\000\020\000\021\000\031\000\027\000\057\000\071\000\057\000\
\032\000\065\000\151\000\050\000\051\000\015\000\015\000\057\000\
\081\000\001\000\003\000\156\000\024\000\037\000\052\000\016\000\
\041\000\041\000\021\000\056\000\045\000\045\000\015\000\004\000\
\147\000\004\000\116\000\026\000\065\000\080\000\072\000\028\000\
\041\000\107\000\005\000\033\000\005\000\037\000\059\000\057\000\
\041\000\117\000\063\000\057\000\041\000\119\000\120\000\121\000\
\122\000\006\000\125\000\006\000\126\000\041\000\070\000\041\000\
\053\000\067\000\055\000\073\000\074\000\057\000\034\000\149\000\
\067\000\041\000\067\000\029\000\007\000\087\000\007\000\041\000\
\053\000\087\000\067\000\087\000\157\000\158\000\159\000\160\000\
\161\000\162\000\163\000\164\000\165\000\166\000\167\000\168\000\
\169\000\170\000\030\000\171\000\172\000\173\000\174\000\075\000\
\060\000\054\000\054\000\015\000\177\000\057\000\178\000\087\000\
\034\000\054\000\067\000\054\000\062\000\064\000\067\000\054\000\
\015\000\054\000\153\000\054\000\154\000\176\000\085\000\154\000\
\054\000\054\000\179\000\015\000\154\000\091\000\054\000\091\000\
\181\000\054\000\054\000\054\000\054\000\054\000\066\000\067\000\
\082\000\082\000\015\000\092\000\054\000\092\000\054\000\015\000\
\082\000\068\000\082\000\054\000\054\000\054\000\082\000\054\000\
\082\000\078\000\082\000\054\000\054\000\015\000\086\000\082\000\
\082\000\077\000\084\000\082\000\115\000\082\000\116\000\118\000\
\082\000\082\000\082\000\082\000\082\000\145\000\048\000\081\000\
\081\000\034\000\037\000\082\000\127\000\082\000\039\000\081\000\
\025\000\081\000\082\000\082\000\082\000\081\000\082\000\081\000\
\058\000\081\000\069\000\082\000\040\000\049\000\081\000\081\000\
\015\000\148\000\114\000\035\000\081\000\112\000\150\000\081\000\
\081\000\081\000\081\000\081\000\000\000\000\000\080\000\080\000\
\000\000\000\000\081\000\000\000\081\000\036\000\080\000\000\000\
\080\000\081\000\081\000\081\000\080\000\081\000\080\000\000\000\
\080\000\000\000\081\000\000\000\000\000\080\000\080\000\000\000\
\000\000\000\000\000\000\080\000\000\000\000\000\080\000\080\000\
\080\000\080\000\080\000\000\000\000\000\079\000\079\000\000\000\
\000\000\080\000\000\000\080\000\000\000\079\000\000\000\079\000\
\080\000\080\000\080\000\079\000\080\000\079\000\000\000\079\000\
\000\000\080\000\000\000\000\000\079\000\079\000\041\000\000\000\
\000\000\000\000\079\000\000\000\000\000\079\000\079\000\079\000\
\079\000\079\000\000\000\041\000\128\000\129\000\000\000\000\000\
\079\000\000\000\079\000\000\000\000\000\000\000\041\000\079\000\
\079\000\079\000\130\000\079\000\131\000\000\000\000\000\000\000\
\079\000\000\000\000\000\132\000\133\000\041\000\000\000\000\000\
\000\000\134\000\000\000\000\000\135\000\136\000\137\000\138\000\
\139\000\000\000\000\000\128\000\129\000\000\000\000\000\140\000\
\041\000\141\000\072\000\072\000\000\000\000\000\142\000\143\000\
\144\000\130\000\072\000\131\000\072\000\000\000\145\000\146\000\
\000\000\000\000\132\000\133\000\072\000\000\000\000\000\000\000\
\134\000\000\000\000\000\135\000\136\000\137\000\138\000\139\000\
\000\000\000\000\128\000\129\000\000\000\000\000\140\000\000\000\
\141\000\000\000\000\000\000\000\000\000\072\000\143\000\144\000\
\130\000\152\000\131\000\000\000\072\000\145\000\146\000\000\000\
\072\000\132\000\133\000\000\000\000\000\072\000\000\000\134\000\
\000\000\000\000\135\000\136\000\137\000\138\000\139\000\000\000\
\000\000\128\000\129\000\000\000\000\000\140\000\000\000\141\000\
\073\000\073\000\000\000\000\000\175\000\143\000\144\000\130\000\
\073\000\131\000\073\000\180\000\145\000\146\000\000\000\000\000\
\132\000\133\000\073\000\000\000\000\000\000\000\134\000\000\000\
\000\000\135\000\136\000\137\000\138\000\139\000\000\000\000\000\
\128\000\129\000\000\000\000\000\140\000\000\000\141\000\000\000\
\000\000\000\000\000\000\073\000\143\000\144\000\130\000\085\000\
\131\000\000\000\073\000\145\000\146\000\000\000\073\000\132\000\
\133\000\000\000\000\000\073\000\000\000\134\000\000\000\000\000\
\135\000\136\000\137\000\138\000\139\000\000\000\084\000\084\000\
\015\000\000\000\130\000\140\000\000\000\141\000\084\000\000\000\
\084\000\000\000\000\000\143\000\144\000\000\000\084\000\086\000\
\084\000\000\000\145\000\146\000\000\000\084\000\084\000\138\000\
\000\000\000\000\113\000\084\000\000\000\000\000\084\000\084\000\
\084\000\000\000\084\000\043\000\000\000\083\000\083\000\143\000\
\144\000\084\000\000\000\084\000\000\000\083\000\145\000\083\000\
\084\000\000\000\000\000\054\000\084\000\083\000\000\000\083\000\
\000\000\084\000\000\000\061\000\083\000\083\000\000\000\000\000\
\000\000\128\000\083\000\000\000\000\000\083\000\083\000\083\000\
\043\000\083\000\000\000\077\000\077\000\000\000\000\000\130\000\
\083\000\131\000\083\000\077\000\000\000\077\000\000\000\083\000\
\132\000\133\000\000\000\083\000\000\000\077\000\134\000\000\000\
\083\000\135\000\136\000\137\000\138\000\139\000\000\000\061\000\
\061\000\071\000\000\000\000\000\140\000\000\000\141\000\061\000\
\071\000\061\000\071\000\000\000\143\000\144\000\077\000\061\000\
\000\000\061\000\071\000\145\000\146\000\077\000\061\000\061\000\
\000\000\077\000\078\000\078\000\061\000\000\000\077\000\061\000\
\061\000\000\000\078\000\061\000\078\000\000\000\070\000\070\000\
\000\000\000\000\061\000\071\000\078\000\000\000\070\000\000\000\
\070\000\061\000\071\000\000\000\000\000\061\000\071\000\000\000\
\070\000\000\000\061\000\071\000\075\000\075\000\000\000\000\000\
\000\000\000\000\000\000\000\000\075\000\078\000\075\000\000\000\
\000\000\000\000\000\000\000\000\078\000\000\000\075\000\000\000\
\078\000\070\000\000\000\076\000\076\000\078\000\074\000\074\000\
\070\000\000\000\000\000\076\000\070\000\076\000\074\000\000\000\
\074\000\070\000\000\000\000\000\000\000\076\000\000\000\075\000\
\074\000\000\000\000\000\000\000\000\000\000\000\075\000\000\000\
\000\000\069\000\075\000\000\000\000\000\000\000\000\000\075\000\
\069\000\000\000\069\000\000\000\000\000\128\000\076\000\000\000\
\000\000\074\000\069\000\000\000\000\000\076\000\000\000\000\000\
\074\000\076\000\000\000\130\000\074\000\131\000\076\000\000\000\
\000\000\074\000\000\000\000\000\132\000\133\000\000\000\000\000\
\000\000\000\000\134\000\069\000\000\000\135\000\136\000\137\000\
\138\000\139\000\069\000\000\000\000\000\000\000\069\000\000\000\
\155\000\000\000\141\000\069\000\093\000\094\000\000\000\000\000\
\143\000\144\000\000\000\000\000\095\000\000\000\000\000\145\000\
\000\000\000\000\096\000\015\000\097\000\000\000\098\000\000\000\
\000\000\130\000\099\000\000\000\000\000\000\000\000\000\100\000\
\000\000\130\000\101\000\131\000\000\000\000\000\102\000\103\000\
\104\000\000\000\132\000\133\000\000\000\137\000\138\000\105\000\
\134\000\000\000\000\000\135\000\136\000\137\000\138\000\139\000\
\141\000\000\000\093\000\094\000\000\000\000\000\143\000\144\000\
\141\000\000\000\095\000\000\000\000\000\145\000\143\000\144\000\
\096\000\015\000\097\000\000\000\098\000\145\000\000\000\000\000\
\099\000\000\000\000\000\000\000\000\000\100\000\000\000\000\000\
\101\000\000\000\000\000\000\000\102\000\103\000\104\000\000\000\
\000\000\000\000\000\000\000\000\000\000\105\000"

let yycheck = "\004\000\
\005\000\006\000\007\000\013\001\018\001\011\001\068\000\013\001\
\018\001\057\000\118\000\012\001\013\001\030\001\030\001\021\001\
\078\000\001\000\001\001\127\000\001\001\026\000\011\001\028\000\
\029\000\030\000\031\000\011\001\045\001\045\001\030\001\014\001\
\011\001\014\001\013\001\012\001\084\000\053\001\011\001\053\001\
\045\000\085\000\025\001\053\001\025\001\050\000\051\000\053\001\
\053\000\093\000\055\000\057\001\057\000\097\000\098\000\099\000\
\100\000\040\001\102\000\040\001\104\000\066\000\067\000\068\000\
\053\001\004\001\061\001\011\001\018\001\053\001\011\001\115\000\
\011\001\078\000\013\001\045\001\059\001\082\000\059\001\084\000\
\053\001\086\000\021\001\088\000\128\000\129\000\130\000\131\000\
\132\000\133\000\134\000\135\000\136\000\137\000\138\000\139\000\
\140\000\141\000\045\001\143\000\144\000\145\000\146\000\053\001\
\052\001\003\001\004\001\001\001\152\000\053\001\154\000\116\000\
\053\001\011\001\053\001\013\001\011\001\052\001\057\001\017\001\
\014\001\019\001\011\001\021\001\013\001\011\001\005\001\013\001\
\026\001\027\001\011\001\025\001\013\001\011\001\032\001\013\001\
\180\000\035\001\036\001\037\001\038\001\039\001\045\001\061\001\
\003\001\004\001\040\001\011\001\046\001\013\001\048\001\030\001\
\011\001\045\001\013\001\053\001\054\001\055\001\017\001\057\001\
\019\001\060\001\021\001\061\001\062\001\059\001\045\001\026\001\
\027\001\053\001\053\001\034\001\019\001\032\001\013\001\045\001\
\035\001\036\001\037\001\038\001\039\001\061\001\019\001\003\001\
\004\001\007\001\034\001\046\001\045\001\048\001\034\001\011\001\
\009\000\013\001\053\001\054\001\055\001\017\001\057\001\019\001\
\050\000\021\001\066\000\062\001\028\000\031\000\026\001\027\001\
\030\001\113\000\088\000\033\001\032\001\086\000\116\000\035\001\
\036\001\037\001\038\001\039\001\255\255\255\255\003\001\004\001\
\255\255\255\255\046\001\255\255\048\001\051\001\011\001\255\255\
\013\001\053\001\054\001\055\001\017\001\057\001\019\001\255\255\
\021\001\255\255\062\001\255\255\255\255\026\001\027\001\255\255\
\255\255\255\255\255\255\032\001\255\255\255\255\035\001\036\001\
\037\001\038\001\039\001\255\255\255\255\003\001\004\001\255\255\
\255\255\046\001\255\255\048\001\255\255\011\001\255\255\013\001\
\053\001\054\001\055\001\017\001\057\001\019\001\255\255\021\001\
\255\255\062\001\255\255\255\255\026\001\027\001\001\001\255\255\
\255\255\255\255\032\001\255\255\255\255\035\001\036\001\037\001\
\038\001\039\001\255\255\014\001\003\001\004\001\255\255\255\255\
\046\001\255\255\048\001\255\255\255\255\255\255\025\001\053\001\
\054\001\055\001\017\001\057\001\019\001\255\255\255\255\255\255\
\062\001\255\255\255\255\026\001\027\001\040\001\255\255\255\255\
\255\255\032\001\255\255\255\255\035\001\036\001\037\001\038\001\
\039\001\255\255\255\255\003\001\004\001\255\255\255\255\046\001\
\059\001\048\001\003\001\004\001\255\255\255\255\053\001\054\001\
\055\001\017\001\011\001\019\001\013\001\255\255\061\001\062\001\
\255\255\255\255\026\001\027\001\021\001\255\255\255\255\255\255\
\032\001\255\255\255\255\035\001\036\001\037\001\038\001\039\001\
\255\255\255\255\003\001\004\001\255\255\255\255\046\001\255\255\
\048\001\255\255\255\255\255\255\255\255\046\001\054\001\055\001\
\017\001\057\001\019\001\255\255\053\001\061\001\062\001\255\255\
\057\001\026\001\027\001\255\255\255\255\062\001\255\255\032\001\
\255\255\255\255\035\001\036\001\037\001\038\001\039\001\255\255\
\255\255\003\001\004\001\255\255\255\255\046\001\255\255\048\001\
\003\001\004\001\255\255\255\255\053\001\054\001\055\001\017\001\
\011\001\019\001\013\001\021\001\061\001\062\001\255\255\255\255\
\026\001\027\001\021\001\255\255\255\255\255\255\032\001\255\255\
\255\255\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\003\001\004\001\255\255\255\255\046\001\255\255\048\001\255\255\
\255\255\255\255\255\255\046\001\054\001\055\001\017\001\005\001\
\019\001\255\255\053\001\061\001\062\001\255\255\057\001\026\001\
\027\001\255\255\255\255\062\001\255\255\032\001\255\255\255\255\
\035\001\036\001\037\001\038\001\039\001\255\255\003\001\004\001\
\030\001\255\255\017\001\046\001\255\255\048\001\011\001\255\255\
\013\001\255\255\255\255\054\001\055\001\255\255\019\001\045\001\
\021\001\255\255\061\001\062\001\255\255\026\001\027\001\038\001\
\255\255\255\255\056\001\032\001\255\255\255\255\035\001\036\001\
\037\001\255\255\039\001\029\000\255\255\003\001\004\001\054\001\
\055\001\046\001\255\255\048\001\255\255\011\001\061\001\013\001\
\053\001\255\255\255\255\045\000\057\001\019\001\255\255\021\001\
\255\255\062\001\255\255\053\000\026\001\027\001\255\255\255\255\
\255\255\003\001\032\001\255\255\255\255\035\001\036\001\037\001\
\066\000\039\001\255\255\003\001\004\001\255\255\255\255\017\001\
\046\001\019\001\048\001\011\001\255\255\013\001\255\255\053\001\
\026\001\027\001\255\255\057\001\255\255\021\001\032\001\255\255\
\062\001\035\001\036\001\037\001\038\001\039\001\255\255\003\001\
\004\001\004\001\255\255\255\255\046\001\255\255\048\001\011\001\
\011\001\013\001\013\001\255\255\054\001\055\001\046\001\019\001\
\255\255\021\001\021\001\061\001\062\001\053\001\026\001\027\001\
\255\255\057\001\003\001\004\001\032\001\255\255\062\001\035\001\
\036\001\255\255\011\001\039\001\013\001\255\255\003\001\004\001\
\255\255\255\255\046\001\046\001\021\001\255\255\011\001\255\255\
\013\001\053\001\053\001\255\255\255\255\057\001\057\001\255\255\
\021\001\255\255\062\001\062\001\003\001\004\001\255\255\255\255\
\255\255\255\255\255\255\255\255\011\001\046\001\013\001\255\255\
\255\255\255\255\255\255\255\255\053\001\255\255\021\001\255\255\
\057\001\046\001\255\255\003\001\004\001\062\001\003\001\004\001\
\053\001\255\255\255\255\011\001\057\001\013\001\011\001\255\255\
\013\001\062\001\255\255\255\255\255\255\021\001\255\255\046\001\
\021\001\255\255\255\255\255\255\255\255\255\255\053\001\255\255\
\255\255\004\001\057\001\255\255\255\255\255\255\255\255\062\001\
\011\001\255\255\013\001\255\255\255\255\003\001\046\001\255\255\
\255\255\046\001\021\001\255\255\255\255\053\001\255\255\255\255\
\053\001\057\001\255\255\017\001\057\001\019\001\062\001\255\255\
\255\255\062\001\255\255\255\255\026\001\027\001\255\255\255\255\
\255\255\255\255\032\001\046\001\255\255\035\001\036\001\037\001\
\038\001\039\001\053\001\255\255\255\255\255\255\057\001\255\255\
\011\001\255\255\048\001\062\001\015\001\016\001\255\255\255\255\
\054\001\055\001\255\255\255\255\023\001\255\255\255\255\061\001\
\255\255\255\255\029\001\030\001\031\001\255\255\033\001\255\255\
\255\255\017\001\037\001\255\255\255\255\255\255\255\255\042\001\
\255\255\017\001\045\001\019\001\255\255\255\255\049\001\050\001\
\051\001\255\255\026\001\027\001\255\255\037\001\038\001\058\001\
\032\001\255\255\255\255\035\001\036\001\037\001\038\001\039\001\
\048\001\255\255\015\001\016\001\255\255\255\255\054\001\055\001\
\048\001\255\255\023\001\255\255\255\255\061\001\054\001\055\001\
\029\001\030\001\031\001\255\255\033\001\061\001\255\255\255\255\
\037\001\255\255\255\255\255\255\255\255\042\001\255\255\255\255\
\045\001\255\255\255\255\255\255\049\001\050\001\051\001\255\255\
\255\255\255\255\255\255\255\255\255\255\058\001"

let yynames_const = "\
  TK_EOF\000\
  "

let yynames_block = "\
  TK_ERROR\000\
  TK_AND\000\
  TK_ARROW\000\
  TK_ASSERT\000\
  TK_BAR\000\
  TK_BOOL\000\
  TK_CDOTS\000\
  TK_CLOSE_BRACE\000\
  TK_CLOSE_BRACKET\000\
  TK_CLOSE_PAR\000\
  TK_COLON\000\
  TK_COMA\000\
  TK_CONST\000\
  TK_CURRENT\000\
  TK_DIESE\000\
  TK_DIV\000\
  TK_DOT\000\
  TK_EQ\000\
  TK_EQUA\000\
  TK_ELSE\000\
  TK_ENUM\000\
  TK_FALSE\000\
  TK_FIELD\000\
  TK_FUNCTION\000\
  TK_GT\000\
  TK_GTE\000\
  TK_HAT\000\
  TK_ICONST\000\
  TK_IDENT\000\
  TK_IF\000\
  TK_IMPL\000\
  TK_INT\000\
  TK_LET\000\
  TK_LT\000\
  TK_LTE\000\
  TK_MINUS\000\
  TK_MOD\000\
  TK_NEQ\000\
  TK_NODE\000\
  TK_NOR\000\
  TK_NOT\000\
  TK_OPEN_BRACE\000\
  TK_OPEN_BRACKET\000\
  TK_OPEN_PAR\000\
  TK_OR\000\
  TK_PCENT\000\
  TK_PLUS\000\
  TK_PRE\000\
  TK_RCONST\000\
  TK_REAL\000\
  TK_RETURNS\000\
  TK_SEMICOL\000\
  TK_SLASH\000\
  TK_STAR\000\
  TK_TEL\000\
  TK_THEN\000\
  TK_TRUE\000\
  TK_TYPE\000\
  TK_VAR\000\
  TK_WHEN\000\
  TK_XOR\000\
  TK_OF\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    Obj.repr(
# 179 "src/xec/xecParser.mly"
                   (
			{
      		const_table = !const_table;
      		type_table  = !type_table;
      		oper_table  = !oper_table;
      		def_list    = (List.rev !def_list)
   		}
	)
# 619 "src/xec/xecParser.ml"
               : Syntaxe.package))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'xecDeclList) in
    Obj.repr(
# 189 "src/xec/xecParser.mly"
  ( 
			{
      		const_table = !const_table;
      		type_table  = !type_table;
      		oper_table  = !oper_table;
      		def_list    = (List.rev !def_list)
   		}
		 )
# 633 "src/xec/xecParser.ml"
               : Syntaxe.package))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecDecl) in
    Obj.repr(
# 203 "src/xec/xecParser.mly"
   ( )
# 640 "src/xec/xecParser.ml"
               : 'xecDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'xecDeclList) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecDecl) in
    Obj.repr(
# 205 "src/xec/xecParser.mly"
   ( )
# 648 "src/xec/xecParser.ml"
               : 'xecDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecConstDecl) in
    Obj.repr(
# 209 "src/xec/xecParser.mly"
               ( )
# 655 "src/xec/xecParser.ml"
               : 'xecDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecTypeDecl) in
    Obj.repr(
# 210 "src/xec/xecParser.mly"
               ( )
# 662 "src/xec/xecParser.ml"
               : 'xecDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecFuncDecl) in
    Obj.repr(
# 211 "src/xec/xecParser.mly"
               ( )
# 669 "src/xec/xecParser.ml"
               : 'xecDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecNodeDecl) in
    Obj.repr(
# 212 "src/xec/xecParser.mly"
               ( )
# 676 "src/xec/xecParser.ml"
               : 'xecDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 219 "src/xec/xecParser.mly"
 ( _1 )
# 683 "src/xec/xecParser.ml"
               : 'xecIdent))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 223 "src/xec/xecParser.mly"
   ( [_1.str] )
# 690 "src/xec/xecParser.ml"
               : 'xecIdentList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecIdentList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 225 "src/xec/xecParser.mly"
   ( (_3.str)::_1 )
# 699 "src/xec/xecParser.ml"
               : 'xecIdentList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecIdentList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecType) in
    Obj.repr(
# 230 "src/xec/xecParser.mly"
 ( (_1, _3) )
# 708 "src/xec/xecParser.ml"
               : 'xecTypedIdents))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecTypedIdents) in
    Obj.repr(
# 235 "src/xec/xecParser.mly"
 (
		List.map (add_type_to_var (snd _1)) (fst _1)
	)
# 717 "src/xec/xecParser.ml"
               : 'xecTypedIdentsList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecTypedIdentsList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecTypedIdents) in
    Obj.repr(
# 239 "src/xec/xecParser.mly"
 (
		(List.map (add_type_to_var (snd _3)) (fst _3)) @ _1
	)
# 728 "src/xec/xecParser.ml"
               : 'xecTypedIdentsList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecConstDeclList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 249 "src/xec/xecParser.mly"
   ()
# 737 "src/xec/xecParser.ml"
               : 'xecConstDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecConstDeclList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 251 "src/xec/xecParser.mly"
   ()
# 746 "src/xec/xecParser.ml"
               : 'xecConstDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecOneConstDecl) in
    Obj.repr(
# 255 "src/xec/xecParser.mly"
   ()
# 753 "src/xec/xecParser.ml"
               : 'xecConstDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecConstDeclList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecOneConstDecl) in
    Obj.repr(
# 257 "src/xec/xecParser.mly"
   ()
# 762 "src/xec/xecParser.ml"
               : 'xecConstDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecIdent) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecType) in
    Obj.repr(
# 263 "src/xec/xecParser.mly"
   ( add_constant _1 (ExternalConst (_1.str, _3)) )
# 771 "src/xec/xecParser.ml"
               : 'xecOneConstDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecTypeDeclList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 270 "src/xec/xecParser.mly"
   ()
# 780 "src/xec/xecParser.ml"
               : 'xecTypeDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecTypeDeclList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 272 "src/xec/xecParser.mly"
   ()
# 789 "src/xec/xecParser.ml"
               : 'xecTypeDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecOneTypeDecl) in
    Obj.repr(
# 276 "src/xec/xecParser.mly"
   ()
# 796 "src/xec/xecParser.ml"
               : 'xecTypeDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecTypeDeclList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecOneTypeDecl) in
    Obj.repr(
# 278 "src/xec/xecParser.mly"
   ()
# 805 "src/xec/xecParser.ml"
               : 'xecTypeDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 284 "src/xec/xecParser.mly"
   ( add_type _1 (ExternalType _1.str) )
# 812 "src/xec/xecParser.ml"
               : 'xecOneTypeDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecPredefinedType) in
    Obj.repr(
# 291 "src/xec/xecParser.mly"
   ( _1 )
# 819 "src/xec/xecParser.ml"
               : 'xecType))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 294 "src/xec/xecParser.mly"
   ( (NamedType _1.str) )
# 826 "src/xec/xecParser.ml"
               : 'xecType))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 308 "src/xec/xecParser.mly"
   ( Bool )
# 833 "src/xec/xecParser.ml"
               : 'xecPredefinedType))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 310 "src/xec/xecParser.mly"
   ( Int )
# 840 "src/xec/xecParser.ml"
               : 'xecPredefinedType))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 312 "src/xec/xecParser.mly"
   ( Real )
# 847 "src/xec/xecParser.ml"
               : 'xecPredefinedType))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 9 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'xecIdent) in
    let _3 = (Parsing.peek_val __caml_parser_env 7 : Lexeme.t) in
    let _4 = (Parsing.peek_val __caml_parser_env 6 : 'xecTypedIdentsList) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : Lexeme.t) in
    let _6 = (Parsing.peek_val __caml_parser_env 4 : Lexeme.t) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : Lexeme.t) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'xecTypedIdentsList) in
    let _9 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _10 = (Parsing.peek_val __caml_parser_env 0 : 'xecOptEnding) in
    Obj.repr(
# 322 "src/xec/xecParser.mly"
 ( 
		let finfo = {
			fi_name = _2.str;
			fi_inpars = (List.rev _4);
			fi_outpars = (List.rev _8);
		} in
		(add_oper _2 (FuncOper finfo))
	)
# 870 "src/xec/xecParser.ml"
               : 'xecFuncDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 11 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 10 : 'xecIdent) in
    let _3 = (Parsing.peek_val __caml_parser_env 9 : Lexeme.t) in
    let _4 = (Parsing.peek_val __caml_parser_env 8 : 'xecVarDeclList) in
    let _5 = (Parsing.peek_val __caml_parser_env 7 : Lexeme.t) in
    let _6 = (Parsing.peek_val __caml_parser_env 6 : Lexeme.t) in
    let _7 = (Parsing.peek_val __caml_parser_env 5 : Lexeme.t) in
    let _8 = (Parsing.peek_val __caml_parser_env 4 : 'xecVarDeclList) in
    let _9 = (Parsing.peek_val __caml_parser_env 3 : Lexeme.t) in
    let _10 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _11 = (Parsing.peek_val __caml_parser_env 1 : 'xecLocals) in
    let _12 = (Parsing.peek_val __caml_parser_env 0 : 'xecNodeBody) in
    Obj.repr(
# 340 "src/xec/xecParser.mly"
 (
		let ninfo = {
			ni_name = _2.str ;
			ni_inputs = List.rev _4 ;
			ni_outputs = List.rev _8 ;
			ni_locals = List.rev _11 ;
			ni_asserts = List.rev (fst _12) ;
			ni_defs = List.rev (snd _12)
		} in (add_oper _2 (NodeOper ninfo))
	)
# 897 "src/xec/xecParser.ml"
               : 'xecNodeDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecVarDecl) in
    Obj.repr(
# 354 "src/xec/xecParser.mly"
   ( _1 )
# 904 "src/xec/xecParser.ml"
               : 'xecVarDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecVarDeclList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecVarDecl) in
    Obj.repr(
# 356 "src/xec/xecParser.mly"
   ( _3@_1 )
# 913 "src/xec/xecParser.ml"
               : 'xecVarDeclList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecTypedIdents) in
    Obj.repr(
# 361 "src/xec/xecParser.mly"
 (
		List.map (add_type_n_clock_to_var (snd _1) BaseClock) (fst _1)
	)
# 922 "src/xec/xecParser.ml"
               : 'xecVarDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecTypedIdents) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 365 "src/xec/xecParser.mly"
 (
		List.map (add_type_n_clock_to_var (snd _1) (NamedClock _3.str)) (fst _1)
	)
# 933 "src/xec/xecParser.ml"
               : 'xecVarDecl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'xecTypedIdents) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 369 "src/xec/xecParser.mly"
 (
		List.map (add_type_n_clock_to_var (snd _2) (NamedClock _5.str)) (fst _2)
	)
# 946 "src/xec/xecParser.ml"
               : 'xecVarDecl))
; (fun __caml_parser_env ->
    Obj.repr(
# 375 "src/xec/xecParser.mly"
   ( [] )
# 952 "src/xec/xecParser.ml"
               : 'xecLocals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 376 "src/xec/xecParser.mly"
                         ( [] )
# 960 "src/xec/xecParser.ml"
               : 'xecLocals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecVarDeclList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 377 "src/xec/xecParser.mly"
                                       ( _2 )
# 969 "src/xec/xecParser.ml"
               : 'xecLocals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'xecEquaList) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'xecOptEnding) in
    Obj.repr(
# 386 "src/xec/xecParser.mly"
    ( _2 )
# 979 "src/xec/xecParser.ml"
               : 'xecNodeBody))
; (fun __caml_parser_env ->
    Obj.repr(
# 390 "src/xec/xecParser.mly"
              ()
# 985 "src/xec/xecParser.ml"
               : 'xecOptEnding))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 390 "src/xec/xecParser.mly"
                              ()
# 992 "src/xec/xecParser.ml"
               : 'xecOptEnding))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 390 "src/xec/xecParser.mly"
                                          ()
# 999 "src/xec/xecParser.ml"
               : 'xecOptEnding))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecEqua) in
    Obj.repr(
# 396 "src/xec/xecParser.mly"
   ( _1 )
# 1006 "src/xec/xecParser.ml"
               : 'xecEquaList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'xecEquaList) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecEqua) in
    Obj.repr(
# 398 "src/xec/xecParser.mly"
   ( ((fst _2)@(fst _1), (snd _2)@(snd _1)) )
# 1014 "src/xec/xecParser.ml"
               : 'xecEquaList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecExp) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 402 "src/xec/xecParser.mly"
   ( ([_2], []) )
# 1023 "src/xec/xecParser.ml"
               : 'xecEqua))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'xecLeft) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'xecExp) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 404 "src/xec/xecParser.mly"
   ( ([], [(List.rev _1, _3)]) )
# 1033 "src/xec/xecParser.ml"
               : 'xecEqua))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecLeftItemList) in
    Obj.repr(
# 411 "src/xec/xecParser.mly"
  ( _1 )
# 1040 "src/xec/xecParser.ml"
               : 'xecLeft))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecLeftItemList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 413 "src/xec/xecParser.mly"
  ( _2 )
# 1049 "src/xec/xecParser.ml"
               : 'xecLeft))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecLeftItem) in
    Obj.repr(
# 417 "src/xec/xecParser.mly"
   ( [_1] )
# 1056 "src/xec/xecParser.ml"
               : 'xecLeftItemList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecLeftItemList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecLeftItem) in
    Obj.repr(
# 419 "src/xec/xecParser.mly"
   ( _3::_1 )
# 1065 "src/xec/xecParser.ml"
               : 'xecLeftItemList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 424 "src/xec/xecParser.mly"
  ( (LeftVar _1.str) )
# 1072 "src/xec/xecParser.ml"
               : 'xecLeftItem))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecConst) in
    Obj.repr(
# 431 "src/xec/xecParser.mly"
             ( make_val_exp _1 [] )
# 1079 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecIdent) in
    Obj.repr(
# 432 "src/xec/xecParser.mly"
              ( make_val_exp (IDENT_n _1.str) [] )
# 1086 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecUnaryExp) in
    Obj.repr(
# 433 "src/xec/xecParser.mly"
               ( _1 )
# 1093 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecBinaryExp) in
    Obj.repr(
# 434 "src/xec/xecParser.mly"
                ( _1 )
# 1100 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'xecExp) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Lexeme.t) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 436 "src/xec/xecParser.mly"
   ( make_val_exp IF_n [_2; _4; _6] )
# 1112 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecCallExp) in
    Obj.repr(
# 438 "src/xec/xecParser.mly"
   ( _1 )
# 1119 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'xecExpList) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 441 "src/xec/xecParser.mly"
  ( make_val_exp DIESE_n (List.rev _3) )
# 1129 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'xecExpList) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 445 "src/xec/xecParser.mly"
  (
			match _2 with
			|	[e] -> e
			|	el  ->  make_val_exp TUPLE_n (List.rev el) )
# 1141 "src/xec/xecParser.ml"
               : 'xecExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 452 "src/xec/xecParser.mly"
                   ( make_val_exp NOT_n [_2] )
# 1149 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 453 "src/xec/xecParser.mly"
                                     ( make_val_exp UMINUS_n [_2] )
# 1157 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 454 "src/xec/xecParser.mly"
                   ( make_val_exp PRE_n [_2] )
# 1165 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 455 "src/xec/xecParser.mly"
                       ( make_val_exp CURRENT_n [_2] )
# 1173 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 456 "src/xec/xecParser.mly"
                   ( make_val_exp REAL2INT_n [_2] )
# 1181 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 457 "src/xec/xecParser.mly"
                    ( make_val_exp INT2REAL_n [_2] )
# 1189 "src/xec/xecParser.ml"
               : 'xecUnaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 461 "src/xec/xecParser.mly"
                         ( make_val_exp ARROW_n [_1; _3] )
# 1198 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 462 "src/xec/xecParser.mly"
                          ( make_val_exp WHEN_n [_1; _3] )
# 1207 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 463 "src/xec/xecParser.mly"
                         ( make_val_exp XOR_n [_1;_3] )
# 1216 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 464 "src/xec/xecParser.mly"
                          ( make_val_exp IMPL_n [_1;_3] )
# 1225 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 465 "src/xec/xecParser.mly"
                        ( make_val_exp OR_n [_1;_3] )
# 1234 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 466 "src/xec/xecParser.mly"
                         ( make_val_exp AND_n [_1;_3] )
# 1243 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 467 "src/xec/xecParser.mly"
                        ( make_val_exp EQ_n [_1;_3] )
# 1252 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 468 "src/xec/xecParser.mly"
                         ( make_val_exp NEQ_n [_1;_3] )
# 1261 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 469 "src/xec/xecParser.mly"
                        ( make_val_exp LT_n [_1;_3] )
# 1270 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 470 "src/xec/xecParser.mly"
                         ( make_val_exp LTE_n [_1;_3] )
# 1279 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 471 "src/xec/xecParser.mly"
                        ( make_val_exp GT_n [_1;_3] )
# 1288 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 472 "src/xec/xecParser.mly"
                         ( make_val_exp GTE_n [_1;_3] )
# 1297 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 473 "src/xec/xecParser.mly"
                          ( make_val_exp TIMES_n [_1;_3] )
# 1306 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 474 "src/xec/xecParser.mly"
                           ( make_val_exp SLASH_n [_1;_3] )
# 1315 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 475 "src/xec/xecParser.mly"
                         ( make_val_exp MOD_n [_1;_3] )
# 1324 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 476 "src/xec/xecParser.mly"
                         ( make_val_exp DIV_n [_1;_3] )
# 1333 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 477 "src/xec/xecParser.mly"
                          ( make_val_exp PLUS_n [_1;_3] )
# 1342 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExp) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 478 "src/xec/xecParser.mly"
                           ( make_val_exp MINUS_n [_1;_3] )
# 1351 "src/xec/xecParser.ml"
               : 'xecBinaryExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'xecIdent) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'xecExpList) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 484 "src/xec/xecParser.mly"
  ( (make_val_exp (CALL_n _1.str) (List.rev _3)) )
# 1361 "src/xec/xecParser.ml"
               : 'xecCallExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecIdent) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 486 "src/xec/xecParser.mly"
  ( (make_val_exp (CALL_n _1.str) []) )
# 1370 "src/xec/xecParser.ml"
               : 'xecCallExp))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 490 "src/xec/xecParser.mly"
           ( TRUE_n )
# 1377 "src/xec/xecParser.ml"
               : 'xecConst))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 491 "src/xec/xecParser.mly"
            ( FALSE_n )
# 1384 "src/xec/xecParser.ml"
               : 'xecConst))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 492 "src/xec/xecParser.mly"
             ( ICONST_n _1.str )
# 1391 "src/xec/xecParser.ml"
               : 'xecConst))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Lexeme.t) in
    Obj.repr(
# 493 "src/xec/xecParser.mly"
             ( RCONST_n _1.str )
# 1398 "src/xec/xecParser.ml"
               : 'xecConst))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 499 "src/xec/xecParser.mly"
   ( [_1] )
# 1405 "src/xec/xecParser.ml"
               : 'xecExpList))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'xecExpList) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Lexeme.t) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'xecExp) in
    Obj.repr(
# 501 "src/xec/xecParser.mly"
   ( _3::_1 )
# 1414 "src/xec/xecParser.ml"
               : 'xecExpList))
(* Entry xecFile *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let xecFile (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Syntaxe.package)
