%{
(*----------------------------------------------------------------
Passage xec -> format interne

xec = extented expanded code = lustre core
----------------------------------------------------------------*)
open Lexing
open Lexeme
open Syntaxe
open XecErrors
open Format
open Str

(* init parse *)
let const_table = ref (Hashtbl.create 50)
let type_table  = ref (Hashtbl.create 50)
let oper_table  = ref (Hashtbl.create 50)
let def_list    = ref []

let add_info
   (htbl   : (string, 'a srcflaged) Hashtbl.t)
   (kindof : string)   (* une string en cas d'erreur   *)
   (lxm  : Lexeme.t)   (* le lexeme en question        *)
   (info : 'a)         (* l'info en question           *)
= (
   try
      let x  = Hashtbl.find htbl lxm.str in
      raise (
         Compile_error ( lxm ,
            (sprintf "bad %s declaration, ident already linked line %d col %d"
               kindof x.src.line x.src.cstart)
         )
      )
   with Not_found -> (
      Hashtbl.add htbl lxm.str {
         src = lxm ;
         it  = info
      }
   )
)

let add_constant (lxm : Lexeme.t) (ci : const_info) = (
	add_info !const_table "constant" lxm ci ;
	def_list := (ConstDef lxm.str) :: !def_list
) 
let add_type (lxm : Lexeme.t) (ci : type_info) = (
	add_info !type_table "type" lxm ci;
	def_list := (TypeDef lxm.str) :: !def_list
)
let add_oper (lxm : Lexeme.t) (ci : oper_info) = (
	add_info !oper_table "operator" lxm ci;
	def_list := (OperDef lxm.str) :: !def_list
)

(* Utilitaire : cre un tripet (var, type, clock) *)
let add_type_n_clock_to_var ty ck var = (var, ty, ck)

let add_type_to_var ty var = (var, ty)

%}

%token TK_EOF

%token <Lexeme.t> TK_ERROR

%token <Lexeme.t> TK_AND
%token <Lexeme.t> TK_ARROW
%token <Lexeme.t> TK_ARROW
%token <Lexeme.t> TK_ASSERT
%token <Lexeme.t> TK_BAR
%token <Lexeme.t> TK_BOOL
%token <Lexeme.t> TK_CDOTS
%token <Lexeme.t> TK_CLOSE_BRACE
%token <Lexeme.t> TK_CLOSE_BRACKET
%token <Lexeme.t> TK_CLOSE_PAR
%token <Lexeme.t> TK_COLON
%token <Lexeme.t> TK_COMA
%token <Lexeme.t> TK_CONST
%token <Lexeme.t> TK_CURRENT
%token <Lexeme.t> TK_DIESE
%token <Lexeme.t> TK_DIV
%token <Lexeme.t> TK_DOT
%token <Lexeme.t> TK_EQ
%token <Lexeme.t> TK_EQUA
%token <Lexeme.t> TK_ELSE
%token <Lexeme.t> TK_ENUM
%token <Lexeme.t> TK_FALSE
%token <Lexeme.t> TK_FIELD
%token <Lexeme.t> TK_FUNCTION
%token <Lexeme.t> TK_GT
%token <Lexeme.t> TK_GTE
%token <Lexeme.t> TK_HAT
%token <Lexeme.t> TK_ICONST
%token <Lexeme.t> TK_IDENT
%token <Lexeme.t> TK_IF
%token <Lexeme.t> TK_IMPL
%token <Lexeme.t> TK_INT
%token <Lexeme.t> TK_LET
%token <Lexeme.t> TK_LT
%token <Lexeme.t> TK_LTE
%token <Lexeme.t> TK_MINUS
%token <Lexeme.t> TK_MOD
%token <Lexeme.t> TK_NEQ
%token <Lexeme.t> TK_NODE
%token <Lexeme.t> TK_NOR
%token <Lexeme.t> TK_NOT
%token <Lexeme.t> TK_OPEN_BRACE
%token <Lexeme.t> TK_OPEN_BRACKET
%token <Lexeme.t> TK_OPEN_PAR
%token <Lexeme.t> TK_OR
%token <Lexeme.t> TK_PCENT
%token <Lexeme.t> TK_PLUS
%token <Lexeme.t> TK_PRE
%token <Lexeme.t> TK_RCONST
%token <Lexeme.t> TK_REAL
%token <Lexeme.t> TK_RETURNS
%token <Lexeme.t> TK_SEMICOL
%token <Lexeme.t> TK_SLASH
%token <Lexeme.t> TK_STAR
%token <Lexeme.t> TK_TEL
%token <Lexeme.t> TK_THEN
%token <Lexeme.t> TK_TRUE
%token <Lexeme.t> TK_TYPE
%token <Lexeme.t> TK_VAR
%token <Lexeme.t> TK_WHEN
%token <Lexeme.t> TK_XOR
%token <Lexeme.t> TK_OF

/* Priorities */

%left TK_ELSE
%left TK_BAR
%left TK_ARROW
%nonassoc TK_CDOTS
%left TK_OR TK_XOR
%left TK_AND
%nonassoc TK_LT TK_LTE TK_EQ TK_GTE TK_GT TK_NEQ TK_IMPL 
%nonassoc TK_NOT
%left TK_PLUS TK_MINUS
%left TK_STAR TK_SLASH TK_PCENT TK_MOD TK_DIV
%left TK_WHEN
%nonassoc TK_INT TK_REAL
%nonassoc TK_UMINUS TK_PRE TK_CURRENT TK_DIESE TK_NOR
%left TK_HAT TK_FIELD TK_DOT
%right TK_OPEN_BRACKET TK_OPEN_BRACE TK_SEMICOL
%right TK_COMA

/* xecEntry point */
%start xecFile
%type <Syntaxe.package> xecFile 

%%

/*-------------------------------------------------------
	GRAMMAR
---------------------------------------------------------
NOTES ON THE CODE:

- Nothing is "built" for the main list declarations :
each definition is directly inserted in the corresponding
hash table (i.e. each declaration makes a side effect)

- Any rule that produces a caml list builds it in THE REVERSE
ORDER (in order to save the yacc stack and to avoid
the use of the caml @ operator). This is why they are
named "sxTotoReverseList". This is why they must not be
used in other rules: onr have to use the corresponding
"sxTotoList" which finally reverse the list.
-------------------------------------------------------*/

/*
WARNING 
La syntaxe ne permet pas de rattacher les bloc equa
a l'entete de node correspondant. On fait donc ca par
effet de bord...
*/

xecFile:
	/* nada */ TK_EOF {
			{
      		const_table = !const_table;
      		type_table  = !type_table;
      		oper_table  = !oper_table;
      		def_list    = (List.rev !def_list)
   		}
	}
|
	xecDeclList TK_EOF
		{ 
			{
      		const_table = !const_table;
      		type_table  = !type_table;
      		oper_table  = !oper_table;
      		def_list    = (List.rev !def_list)
   		}
		 }
	;

/* xecDeclarations */

xecDeclList: /* ebnf:print=expand */
	xecDecl
			{ }
	|   xecDeclList xecDecl
			{ }
	;

xecDecl: /* ebnf:print=short */
		xecConstDecl { }
	|	xecTypeDecl { }
	|	xecFuncDecl { }
	|	xecNodeDecl { }
	;


/* xecIdentifiers and lists */

xecIdent: TK_IDENT
	{ $1 }
	;

xecIdentList: xecIdent
			{ [$1.str] }
	|   xecIdentList TK_COMA xecIdent
			{ ($3.str)::$1 }
	;


xecTypedIdents: xecIdentList TK_COLON xecType
	{ ($1, $3) }
	;


xecTypedIdentsList: xecTypedIdents
	{
		List.map (add_type_to_var (snd $1)) (fst $1)
	}
	|   xecTypedIdentsList TK_SEMICOL xecTypedIdents
	{
		(List.map (add_type_to_var (snd $3)) (fst $3)) @ $1
	}
	;


/* constantes */

xecConstDecl:
	TK_CONST xecConstDeclList TK_SEMICOL
			{}
	| TK_CONST xecConstDeclList TK_DOT
			{}
	;

xecConstDeclList:   xecOneConstDecl
			{}
	|   xecConstDeclList TK_SEMICOL xecOneConstDecl
			{}
	;

xecOneConstDecl: 
	   /* imported */
		xecIdent TK_COLON xecType
			{ add_constant $1 (ExternalConst ($1.str, $3)) }
	; 

/* types */

xecTypeDecl: 
	TK_TYPE xecTypeDeclList TK_SEMICOL
			{}
	| TK_TYPE xecTypeDeclList TK_DOT
			{}
	;

xecTypeDeclList:   xecOneTypeDecl 
			{}
	|   xecTypeDeclList TK_COMA xecOneTypeDecl
			{}
	;

xecOneTypeDecl:
		/* imported type */
		xecIdent
			{ add_type $1 (ExternalType $1.str) }
	;

/* Immediate type */
xecType: /* ebnf:print=short */
		/* predefined */
		xecPredefinedType
			{ $1 }
		/* named */
	|	xecIdent
			{ (NamedType $1.str) }
	;

/*
xecTypeList:
		xecType
			{ [$1] }
	|	xecTypeList TK_COMA xecType
			{ $3::$1 }
	;
*/

xecPredefinedType: /* ebnf:print=short */
	   TK_BOOL 
			{ Bool }
	|   TK_INT 
			{ Int }
	|   TK_REAL
			{ Real }
	;


/* functions (imported nodes) */

xecFuncDecl: 
				TK_FUNCTION xecIdent
            TK_OPEN_PAR xecTypedIdentsList TK_CLOSE_PAR
				TK_RETURNS TK_OPEN_PAR xecTypedIdentsList TK_CLOSE_PAR xecOptEnding
	{ 
		let finfo = {
			fi_name = $2.str;
			fi_inpars = (List.rev $4);
			fi_outpars = (List.rev $8);
		} in
		(add_oper $2 (FuncOper finfo))
	}
	;


/* defined nodes */

xecNodeDecl:
	TK_NODE xecIdent 
	TK_OPEN_PAR xecVarDeclList TK_CLOSE_PAR
	TK_RETURNS TK_OPEN_PAR xecVarDeclList TK_CLOSE_PAR TK_SEMICOL
   xecLocals xecNodeBody
	{
		let ninfo = {
			ni_name = $2.str ;
			ni_inputs = List.rev $4 ;
			ni_outputs = List.rev $8 ;
			ni_locals = List.rev $11 ;
			ni_asserts = List.rev (fst $12) ;
			ni_defs = List.rev (snd $12)
		} in (add_oper $2 (NodeOper ninfo))
	}
	;

xecVarDeclList:
		xecVarDecl
			{ $1 }
	|	xecVarDeclList TK_SEMICOL xecVarDecl
			{ $3@$1 }
	;

xecVarDecl:
	xecTypedIdents
	{
		List.map (add_type_n_clock_to_var (snd $1) BaseClock) (fst $1)
	}
	|	xecTypedIdents TK_WHEN xecIdent
	{
		List.map (add_type_n_clock_to_var (snd $1) (NamedClock $3.str)) (fst $1)
	}
	|	TK_OPEN_PAR xecTypedIdents TK_CLOSE_PAR TK_WHEN xecIdent
	{
		List.map (add_type_n_clock_to_var (snd $2) (NamedClock $5.str)) (fst $2)
	}
	;

xecLocals:	/* empty */
			{ [] }
	|    TK_VAR  TK_SEMICOL { [] }
	|    TK_VAR xecVarDeclList TK_SEMICOL { $2 }
	;

/* node body :
	renvoie un couple (liste d'assert, liste d'equa)
*/

xecNodeBody:
  TK_LET xecEquaList TK_TEL xecOptEnding
			 { $2 }
	;

xecOptEnding: /* ebnf:print=expand */
		/* empty */ {} | TK_SEMICOL {} | TK_DOT {}
	;

/* equations */

xecEquaList:   xecEqua
			{ $1 }
	|   xecEquaList xecEqua
			{ ((fst $2)@(fst $1), (snd $2)@(snd $1)) }
	;

xecEqua:   TK_ASSERT xecExp TK_SEMICOL
			{ ([$2], []) }
	|   xecLeft TK_EQ xecExp TK_SEMICOL
			{ ([], [(List.rev $1, $3)]) }
	;

/* left part : non-empty list of idents */

xecLeft: /* ebnf:print=short */
	   xecLeftItemList
		{ $1 }
	| TK_OPEN_PAR xecLeftItemList TK_CLOSE_PAR
		{ $2 }
	;

xecLeftItemList:   xecLeftItem
			{ [$1] }
	|   xecLeftItemList TK_COMA xecLeftItem 
			{ $3::$1 }
	;

xecLeftItem:
		xecIdent
		{ (LeftVar $1.str) }
	;


/* expression */

xecExp: 
	   xecConst { make_val_exp $1 [] }
	|   xecIdent { make_val_exp (IDENT_n $1.str) [] }
	|	xecUnaryExp { $1 }
	|	xecBinaryExp { $1 }
	|  TK_IF xecExp TK_THEN xecExp TK_ELSE xecExp
			{ make_val_exp IF_n [$2; $4; $6] }
	|	xecCallExp 
			{ $1 }
	/* diese */
	|  TK_DIESE TK_OPEN_PAR xecExpList TK_CLOSE_PAR
		{ make_val_exp DIESE_n (List.rev $3) }
	/* Simple parenthses */
	/* ou Au moins 2 exp => tuple */
	|  TK_OPEN_PAR xecExpList TK_CLOSE_PAR
		{
			match $2 with
			|	[e] -> e
			|	el  ->  make_val_exp TUPLE_n (List.rev el) }
	;

xecUnaryExp:
	    TK_NOT xecExp { make_val_exp NOT_n [$2] }
	|   TK_MINUS xecExp %prec TK_UMINUS { make_val_exp UMINUS_n [$2] }
	|   TK_PRE xecExp { make_val_exp PRE_n [$2] }
	|   TK_CURRENT xecExp { make_val_exp CURRENT_n [$2] }
	|   TK_INT xecExp { make_val_exp REAL2INT_n [$2] }
	|   TK_REAL xecExp { make_val_exp INT2REAL_n [$2] }
;

xecBinaryExp:
		xecExp TK_ARROW xecExp { make_val_exp ARROW_n [$1; $3] }
	|  xecExp TK_WHEN xecExp { make_val_exp WHEN_n [$1; $3] }
	|  xecExp TK_XOR xecExp { make_val_exp XOR_n [$1;$3] }
	|  xecExp TK_IMPL xecExp { make_val_exp IMPL_n [$1;$3] }
	|  xecExp TK_OR xecExp { make_val_exp OR_n [$1;$3] }
	|  xecExp TK_AND xecExp { make_val_exp AND_n [$1;$3] }
	|  xecExp TK_EQ xecExp { make_val_exp EQ_n [$1;$3] }
	|  xecExp TK_NEQ xecExp { make_val_exp NEQ_n [$1;$3] }
	|  xecExp TK_LT xecExp { make_val_exp LT_n [$1;$3] }
	|  xecExp TK_LTE xecExp { make_val_exp LTE_n [$1;$3] }
	|  xecExp TK_GT xecExp { make_val_exp GT_n [$1;$3] }
	|  xecExp TK_GTE xecExp { make_val_exp GTE_n [$1;$3] }
	|  xecExp TK_STAR xecExp { make_val_exp TIMES_n [$1;$3] }
	|  xecExp TK_SLASH xecExp { make_val_exp SLASH_n [$1;$3] }
	|  xecExp TK_MOD xecExp { make_val_exp MOD_n [$1;$3] }
	|  xecExp TK_DIV xecExp { make_val_exp DIV_n [$1;$3] }
	|  xecExp TK_PLUS xecExp { make_val_exp PLUS_n [$1;$3] }
	|  xecExp TK_MINUS xecExp { make_val_exp MINUS_n [$1;$3] }
;

/* call */
xecCallExp:
	xecIdent TK_OPEN_PAR xecExpList TK_CLOSE_PAR
		{ (make_val_exp (CALL_n $1.str) (List.rev $3)) }
|	xecIdent TK_OPEN_PAR TK_CLOSE_PAR
		{ (make_val_exp (CALL_n $1.str) []) }
	;

xecConst: /* ebnf:print=short */
	  TK_TRUE { TRUE_n }
	| TK_FALSE { FALSE_n }
	| TK_ICONST { ICONST_n $1.str }
	| TK_RCONST { RCONST_n $1.str }
	;

/* >= 1 exps */
xecExpList:
		xecExp
			{ [$1] }
	|   xecExpList TK_COMA xecExp 
			{ $3::$1 }
	;
